<?php

$LANG = array(
    'organization' => 'Organizacija',
    'name' => 'Ime',
    'website' => 'Web mjesto',
    'work_phone' => 'Telefon',
    'address' => 'Adresa',
    'address1' => 'Ulica i kućni broj',
    'address2' => 'Kat/Oznaka',
    'city' => 'Grad',
    'state' => 'Županija',
    'postal_code' => 'Poštanski broj',
    'country_id' => 'Zemlja',
    'contacts' => 'Kontakti',
    'first_name' => 'Ime',
    'last_name' => 'Prezime',
    'phone' => 'Telefon',
    'email' => 'E-pošta',
    'additional_info' => 'Dodatne informacije',
    'payment_terms' => 'Uvjeti plaćanja',
    'currency_id' => 'Valuta',
    'size_id' => 'Veličina poduzeća',
    'industry_id' => 'Djelatnost',
    'private_notes' => 'Privatne bilješke',
    'invoice' => 'Račun',
    'client' => 'Klijent',
    'invoice_date' => 'Datum računa',
    'due_date' => 'Datum dospijeća',
    'invoice_number' => 'Broj računa',
    'invoice_number_short' => 'Račun #',
    'po_number' => 'Broj narudžbe',
    'po_number_short' => 'NN #',
    'frequency_id' => 'Koliko često',
    'discount' => 'Popust',
    'taxes' => 'Porezi',
    'tax' => 'Porez',
    'item' => 'Stavka',
    'description' => 'Opis',
    'unit_cost' => 'Jedinična cijena',
    'quantity' => 'Količina',
    'line_total' => 'Ukupno',
    'subtotal' => 'Sveukupno',
    'paid_to_date' => 'Plaćeno na vrijeme',
    'balance_due' => 'Stanje duga',
    'invoice_design_id' => 'Dizajn',
    'terms' => 'Uvjeti',
    'your_invoice' => 'Vaš račun',
    'remove_contact' => 'Ukloni kontakt',
    'add_contact' => 'Dodaj kontakt',
    'create_new_client' => 'Kreiraj novog klijenta',
    'edit_client_details' => 'Uredi detalje klijenta',
    'enable' => 'Omogući',
    'learn_more' => 'Više informacija',
    'manage_rates' => 'Upravljanje ratam',
    'note_to_client' => 'Bilješka klijentu',
    'invoice_terms' => 'Uvjeti računa',
    'save_as_default_terms' => 'Pohrani kao zadane uvjete',
    'download_pdf' => 'Preuzmi PDF',
    'pay_now' => 'Plati odmah',
    'save_invoice' => 'Pohrani račun',
    'clone_invoice' => 'Kopiraj u račun',
    'archive_invoice' => 'Arhiviraj račun',
    'delete_invoice' => 'Obriši račun',
    'email_invoice' => 'Pošalji e-poštom',
    'enter_payment' => 'Unesi uplatu',
    'tax_rates' => 'Porezne stope',
    'rate' => 'Stopa',
    'settings' => 'Postavke',
    'enable_invoice_tax' => 'Omogući specificiranje <b>poreza na računu</b>',
    'enable_line_item_tax' => 'Omogući  specifikaciju <b>poreza na stavci</b>',
    'dashboard' => 'Kontrolna ploča',
    'dashboard_totals_in_all_currencies_help' => 'Napomena: dodajte :link imena ":name" da biste prikazali ukupne iznose koristeći jednu osnovnu valutu.',
    'clients' => 'Klijenti',
    'invoices' => 'Računi',
    'payments' => 'Uplate',
    'credits' => 'Krediti',
    'history' => 'Povijest',
    'search' => 'Pretraga',
    'sign_up' => 'Prijava',
    'guest' => 'Gost',
    'company_details' => 'Detalji poduzeća',
    'online_payments' => 'Online uplate',
    'notifications' => 'Obavijesti',
    'import_export' => 'Uvoz | Izvoz',
    'done' => 'Dovršeno',
    'save' => 'Pohrani',
    'create' => 'Kreiraj',
    'upload' => 'Otpremi',
    'import' => 'Uvoz',
    'download' => 'Preuzmi',
    'cancel' => 'Odustani',
    'close' => 'Zatvori',
    'provide_email' => 'Molim, osigurajte ispravnu adresu e-pošte',
    'powered_by' => 'Powered by',
    'no_items' => 'Nema stavki',
    'recurring_invoices' => 'Redovni računi',
    'recurring_help' => '<p>Automatically send clients the same invoices weekly, bi-monthly, monthly, quarterly or annually. </p>
        <p>Use :MONTH, :QUARTER or :YEAR for dynamic dates. Basic math works as well, for example :MONTH-1.</p>
        <p>Examples of dynamic invoice variables:</p>
        <ul>
          <li>"Gym membership for the month of :MONTH" >> "Gym membership for the month of July"</li>
          <li>":YEAR+1 yearly subscription" >> "2015 Yearly Subscription"</li>
          <li>"Retainer payment for :QUARTER+1" >> "Retainer payment for Q2"</li>
        </ul>',
    'recurring_quotes' => 'Ponavljajuće ponude',
    'in_total_revenue' => 'ukupni prihod',
    'billed_client' => 'fakturirani klijent',
    'billed_clients' => 'fakturairani klijenti',
    'active_client' => 'aktivni klijent',
    'active_clients' => 'aktivni klijenti',
    'invoices_past_due' => 'Računi van valute',
    'upcoming_invoices' => 'Dolazni računi',
    'average_invoice' => 'Prosječni račun',
    'archive' => 'Arhiva',
    'delete' => 'Obriši',
    'archive_client' => 'Arhiviraj klijenta',
    'delete_client' => 'Obriši klijenta',
    'archive_payment' => 'Arhiviraj uplatu',
    'delete_payment' => 'Obriši uplatu',
    'archive_credit' => 'Arhiviraj kredit',
    'delete_credit' => 'Obriši kredit',
    'show_archived_deleted' => 'Prikaži arhivirano/obrisano',
    'filter' => 'Filter',
    'new_client' => 'Novi klijent',
    'new_invoice' => 'Novi račun',
    'new_payment' => 'Unesi uplatu',
    'new_credit' => 'Dodaj kredit',
    'contact' => 'Kontakt',
    'date_created' => 'Datum kreiranja',
    'last_login' => 'Zadnja prijava',
    'balance' => 'Potraživanje',
    'action' => 'Akcija',
    'status' => 'Status',
    'invoice_total' => 'Račun sveukupno',
    'frequency' => 'Frekvencija',
    'range' => 'Raspon',
    'start_date' => 'Početni datum',
    'end_date' => 'Završni datum',
    'transaction_reference' => 'Referenca transakcije',
    'method' => 'Metoda',
    'payment_amount' => 'Iznos uplate',
    'payment_date' => 'Datum uplate',
    'credit_amount' => 'Iznos kredita',
    'credit_balance' => 'Stanje kredita',
    'credit_date' => 'Datum kredita',
    'empty_table' => 'Nema dostupnih podataka u tablici',
    'select' => 'Odaberi',
    'edit_client' => 'Uredi klijenta',
    'edit_invoice' => 'Uredi račun',
    'create_invoice' => 'Kreiraj račun',
    'enter_credit' => 'Unesi kredit',
    'last_logged_in' => 'Zadnja prijava na',
    'details' => 'Detalji',
    'standing' => 'Stanje',
    'credit' => 'Kredit',
    'activity' => 'Aktivnost',
    'date' => 'Datum',
    'message' => 'Poruka',
    'adjustment' => 'Prilagodba',
    'are_you_sure' => 'Da li ste sigurni?',
    'payment_type_id' => 'Tip uplate',
    'amount' => 'Iznos',
    'work_email' => 'E-pošta',
    'language_id' => 'Jezik',
    'timezone_id' => 'Vremnska zona',
    'date_format_id' => 'Format datuma',
    'datetime_format_id' => 'Datum/Vrijeme format',
    'users' => 'Korisnici',
    'localization' => 'Lokalizacija',
    'remove_logo' => 'Ukloni logo',
    'logo_help' => 'Podržano: JPEG, GIF i PNG',
    'payment_gateway' => 'Usmjernik naplate',
    'gateway_id' => 'Usmjernik',
    'email_notifications' => 'Obavijesti e-poštom',
    'email_sent' => 'Obavijesti me e-poštom kada je račun <b>poslan</b>',
    'email_viewed' => 'Obavijesti me e-poštom kada je račun <b>pregledan</b>',
    'email_paid' => 'Obavijest me e-poštom kada je račun <b>plaćen</b>',
    'site_updates' => 'Ažuriranja',
    'custom_messages' => 'Prilagođene poruke',
    'default_email_footer' => 'Postavi zadani <b>potpis e-pošte</b>',
    'select_file' => 'Molim odaberite datoteku',
    'first_row_headers' => 'Koristi prvi redak kao naslovni',
    'column' => 'Kolona',
    'sample' => 'Uzorak',
    'import_to' => 'Uvezi u',
    'client_will_create' => 'klijent će biti kreiran',
    'clients_will_create' => 'klijenti će biti kreirani',
    'email_settings' => 'Postavke e-pošte',
    'client_view_styling' => 'Stil pregleda klijenta',
    'pdf_email_attachment' => 'Priloži račun',
    'custom_css' => 'Prilagođeni CSS',
    'import_clients' => 'Uvezi podatke klijenta',
    'csv_file' => 'CSV datoteka',
    'export_clients' => 'Izvezi podatke klijenta',
    'created_client' => 'Klijent je uspješno kreiran',
    'created_clients' => 'Uspješno kreirano :count kijenata',
    'updated_settings' => 'Postavke su uspješno ažurirane',
    'removed_logo' => 'Logo je uspješno uklonjen',
    'sent_message' => 'Poruka je uspješno poslana',
    'invoice_error' => 'Molimo provjerite da odaberete klijenta i korigirate greške',
    'limit_clients' => 'Nažalost, ovime ćete preći limit od :count klijenata',
    'payment_error' => 'Došlo je do greške pri procesuiranju vaše uplate. Molimo pokušajte kasnije.',
    'registration_required' => 'Molimo prijavite se prije slanja računa e-poštom',
    'confirmation_required' => 'Please confirm your email address, :link to resend the confirmation email.',
    'updated_client' => 'Uspješno ažuriranje klijenta',
    'archived_client' => 'Uspješno arhiviran klijent',
    'archived_clients' => 'Uspješno arhivirano :count klijenata',
    'deleted_client' => 'Uspješno obrisan klijent',
    'deleted_clients' => 'Uspješno obrisano :count klijenata',
    'updated_invoice' => 'Uspješno ažuriran račun',
    'created_invoice' => 'Uspješno kreiran račun',
    'cloned_invoice' => 'Uspješno kloniran račun',
    'emailed_invoice' => 'Račun uspješno poslan e-poštom',
    'and_created_client' => 'i kreiran račun',
    'archived_invoice' => 'Uspješno arhiviran račun',
    'archived_invoices' => 'Uspješno arhivirano :count računa',
    'deleted_invoice' => 'Uspješno obrisan račun',
    'deleted_invoices' => 'Uspješno obrisano :count računa',
    'created_payment' => 'Uspješno kreirana uplata',
    'created_payments' => 'Uspješno kreirano :count uplata',
    'archived_payment' => 'Uspješno arhivirana uplata',
    'archived_payments' => 'Uspješno arhivirana :count uplata',
    'deleted_payment' => 'Uspješno obrisana uplata',
    'deleted_payments' => 'Uspješno obrisano :count uplata',
    'applied_payment' => 'Uspješno primjenjena uplata',
    'created_credit' => 'Uspješno kreiran kredit',
    'archived_credit' => 'Uspješno arhiviran kredit',
    'archived_credits' => 'Uspješno arhivirano :count kredita',
    'deleted_credit' => 'Uspješno obrisan kredit',
    'deleted_credits' => 'Uspješno obrisano :count kredita',
    'imported_file' => 'Uspješno uvezena datoteka',
    'updated_vendor' => 'Uspješno ažuriran dobavljač',
    'created_vendor' => 'Uspješno kreiran dobavljač',
    'archived_vendor' => 'Uspješno arhiviran dobavljač',
    'archived_vendors' => 'Uspješno arhivirano :count dobavljača',
    'deleted_vendor' => 'Uspješno obrisan dobavljač',
    'deleted_vendors' => 'Uspješno obrisano :count dobavljača',
    'confirmation_subject' => 'Invoice Ninja odobravanje računa',
    'confirmation_header' => 'Odobrenje računa',
    'confirmation_message' => 'Molimo pristupite donjom poveznicom za odobrenje vašeg računa.',
    'invoice_subject' => 'Novi račun :number od :account',
    'invoice_message' => 'Za pregled vašeg računa na :amount, kliknite donju poveznicu.',
    'payment_subject' => 'Primljena uplata',
    'payment_message' => 'Hvala vam na vašoj uplati od :amount.',
    'email_salutation' => 'Poštovani/a :name,',
    'email_signature' => 'Srdačno,',
    'email_from' => 'Invoice Ninja tim',
    'invoice_link_message' => 'Za pregled računa kliknite na donju poveznicu:',
    'notification_invoice_paid_subject' => ':client je platio račun :invoice',
    'notification_invoice_sent_subject' => 'Račun :invoice je poslan :client',
    'notification_invoice_viewed_subject' => ':client je pregledao račun :invoice',
    'notification_invoice_paid' => 'Uplata u iznosu :amount je izvršena od strane :client prema računu :invoice.',
    'notification_invoice_sent' => 'Slijedećem klijentu :client je poslan e-poštom račun :invoice na iznos :amount.',
    'notification_invoice_viewed' => 'Slijedeći klijent :client je pregledao račun :invoice na iznos :amount.',
    'reset_password' => 'Možete resetirati zaporku za pristup svom računu klikom na tipku:',
    'secure_payment' => 'Sigurna uplata',
    'card_number' => 'Broj kartice',
    'expiration_month' => 'Mjesec isteka',
    'expiration_year' => 'Godina isteka',
    'cvv' => 'CVV',
    'logout' => 'Odjava',
    'sign_up_to_save' => 'Prijavite se kako bi pohranili učinjeno',
    'agree_to_terms' => 'Slažem se sa Invoice Ninja :terms',
    'terms_of_service' => 'Uvjeti korištenja usluge',
    'email_taken' => 'Ova adresa e-pošte je već registrirana',
    'working' => 'Rad u tijeku',
    'success' => 'Uspjeh',
    'success_message' => 'Uspješno ste se registrirali! Molimo kliknite na poveznicu za potvrdu računa dobivenu e-poštom kako bi verificirali svoju adresu e-pošte.',
    'erase_data' => 'Vaš račun više neće biti registriran, ovo će izbrisati sve vaše podatke.',
    'password' => 'Zaporka',
    'pro_plan_product' => 'Pro Plan',
    'pro_plan_success' => 'Hvala vam na odabiru Invoice Ninja Pro plana!<p/>&nbsp;<br/>
                          <b>Slijedeći koraci</b><p/>Račun je poslan na adresu e-pošte povezanu
                          sa vašim korisničkim računom. Za otključavanje svih naprednih
                          Pro mogućnosti, molimo pratite upute za plaćanje godišnje pretplate
                          za  Invoice Ninja Pro plan.<p/>
                          Ne možete naći račun? Trebate dodatnu pomoć? Sa zadovoljstvom ćemo pomoći
                          -- pošaljite nam e-poštu na contact@invoiceninja.com',
    'unsaved_changes' => 'Imate nepohranjenih promjena',
    'custom_fields' => 'Prilagođena polja',
    'company_fields' => 'Polja poduzeća',
    'client_fields' => 'Polja klijenta',
    'field_label' => 'Oznaka polja',
    'field_value' => 'Vrijednost polja',
    'edit' => 'Uredi',
    'set_name' => 'Postavite ime poduzeća',
    'view_as_recipient' => 'Pregledajte kao primatelj',
    'product_library' => 'Registar proizvoda',
    'product' => 'Proizvod',
    'products' => 'Proizvodi',
    'fill_products' => 'Proizvodi sa samoispunom',
    'fill_products_help' => 'Odabir proizvoda će automatski <b>ispuniti opis i cijenu</b>',
    'update_products' => 'Proizvidi sa autoažuriranjem',
    'update_products_help' => 'Ažuriranje računa automatski <b>ažurirati registar proizvoda</b>',
    'create_product' => 'Dodaj proizvod',
    'edit_product' => 'Uredi proizvod',
    'archive_product' => 'Arhiviraj proizvod',
    'updated_product' => 'Proizvod je uspješno ažuriran',
    'created_product' => 'Proizvod je uspješno kreiran',
    'archived_product' => 'Proizvod je uspješno arhiviran',
    'pro_plan_custom_fields' => ':link za omogućavanje prilagođenih polja aktivacijom Pro plana',
    'advanced_settings' => 'Napredne postavke',
    'pro_plan_advanced_settings' => ':link za omogućavanje naprednih postavki aktivacijom Pro plana',
    'invoice_design' => 'Dizajn računa',
    'specify_colors' => 'Odabir boja',
    'specify_colors_label' => 'Odaberite boje korištenje u računu',
    'chart_builder' => 'Graditelj karte',
    'ninja_email_footer' => 'Created by :site | Create. Send. Get Paid.',
    'go_pro' => 'Go Pro',
    'quote' => 'Ponuda',
    'quotes' => 'Ponude',
    'quote_number' => 'Broj ponude',
    'quote_number_short' => 'Ponuda #',
    'quote_date' => 'Datum ponude',
    'quote_total' => 'Ponuda sveukupno',
    'your_quote' => 'Vaša ponuda',
    'total' => 'Sveukupno',
    'clone' => 'Kloniraj',
    'new_quote' => 'Nova ponuda',
    'create_quote' => 'Kreiraj ponudu',
    'edit_quote' => 'Uredi ponudu',
    'archive_quote' => 'Arhiviraj ponudu',
    'delete_quote' => 'Obriši ponudu',
    'save_quote' => 'Pohrani ponudu',
    'email_quote' => 'Šalji ponudu e-poštom',
    'clone_quote' => 'Kopiraj u ponudu',
    'convert_to_invoice' => 'Konverzija računa',
    'view_invoice' => 'Pregled računa',
    'view_client' => 'Pregled klijenta',
    'view_quote' => 'Pregled ponude',
    'updated_quote' => 'Ponuda je uspješno ažurirana',
    'created_quote' => 'Ponuda uspješno kreirana',
    'cloned_quote' => 'Ponuda uspješno klonirana',
    'emailed_quote' => 'Ponuda uspješno poslana e-poštom',
    'archived_quote' => 'Ponuda uspješno arhivirana',
    'archived_quotes' => 'Uspješno arhivirano :count ponuda',
    'deleted_quote' => 'Ponuda uspješno obrisana',
    'deleted_quotes' => 'Uspješno obrisano :count ponuda',
    'converted_to_invoice' => 'Ponuda uspješno konvertirana u račun',
    'quote_subject' => 'Nova ponuda $quote sa :account',
    'quote_message' => 'Za pregled vaše ponude na :amount, kliknite na donju poveznicu.',
    'quote_link_message' => 'Za pregled ponude vašeg klijenta kliknite na donju poveznicu:',
    'notification_quote_sent_subject' => 'Ponuda :invoice je poslana :client',
    'notification_quote_viewed_subject' => 'Ponuda :invoice je pregledana od :client',
    'notification_quote_sent' => 'Klijentu :client je e-poštom poslana ponuda :invoice na :amount.',
    'notification_quote_viewed' => 'Klijent :client je pregledao ponudu :invoice na :amount.',
    'session_expired' => 'Vaša sjednica je istekla.',
    'invoice_fields' => 'Polja računa',
    'invoice_options' => 'Opcije računa',
    'hide_paid_to_date' => 'Sakrij datum plaćanja',
    'hide_paid_to_date_help' => 'Prikažite "Datum plaćanja" na računima, onda kada je uplata primljena.',
    'charge_taxes' => 'Naplati poreze',
    'user_management' => 'Upravljanje korisnicima',
    'add_user' => 'Dodaj korisnika',
    'send_invite' => 'Pošalji pozivnicu',
    'sent_invite' => 'Uspješno poslana pozivnica',
    'updated_user' => 'Korisnik je uspješno ažuriran',
    'invitation_message' => 'Dobili ste pozivnicu od :invitor.',
    'register_to_add_user' => 'Molimo prijavite se za dodavanje korisnika',
    'user_state' => 'Stanje',
    'edit_user' => 'Uredi korisnika',
    'delete_user' => 'Obriši korisnika',
    'active' => 'Aktivan',
    'pending' => 'Na čekanju',
    'deleted_user' => 'Korisnik je uspješno obrisan',
    'confirm_email_invoice' => 'Da li sigurno želite poslati ovaj račun e-poštom?',
    'confirm_email_quote' => 'Da li sigurno želite poslati ovu ponudu e-poštom?',
    'confirm_recurring_email_invoice' => 'Da li ste sigurni da želite poslati ovaj račun e-poštom?',
    'confirm_recurring_email_invoice_not_sent' => 'Are you sure you want to start the recurrence?',
    'cancel_account' => 'Izbriši korisnički račun',
    'cancel_account_message' => 'Pozor: Ovo će trajno obrisati sve vaše podatke, nema povratka.',
    'go_back' => 'Idi natrag',
    'data_visualizations' => 'Vizualizacije podataka',
    'sample_data' => 'Prikaz primjernih podataka',
    'hide' => 'Sakrij',
    'new_version_available' => 'Nova verzija :releases_link je dostupna. Vi koristite v:user_version, a najnovija je v:latest_version',
    'invoice_settings' => 'Postavke računa',
    'invoice_number_prefix' => 'Prefiks broja računa',
    'invoice_number_counter' => 'Brojač računa',
    'quote_number_prefix' => 'Prefiks broja ponude',
    'quote_number_counter' => 'Brojač ponuda',
    'share_invoice_counter' => 'Dijeljeni brojač računa',
    'invoice_issued_to' => 'Račun izdan',
    'invalid_counter' => 'Za izbjegavanje mogućih konflikata molimo postavite prefiks na broju računa i ponude',
    'mark_sent' => 'Označi kao poslano',
    'gateway_help_1' => ':link za pristup na Authorize.net.',
    'gateway_help_2' => ':link za pristup na Authorize.net.',
    'gateway_help_17' => ':link za pristup vašem PayPal API potpisu.',
    'gateway_help_27' => ':link to sign up for 2Checkout.com. To ensure payments are tracked set :complete_link as the redirect URL under Account > Site Management in the 2Checkout portal.',
    'gateway_help_60' => ':link to create a WePay account.',
    'more_designs' => 'Više dizajna',
    'more_designs_title' => 'Dodatni dizajni računa',
    'more_designs_cloud_header' => 'Nadogradite na Pro za više dizajna računa',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Kupi',
    'bought_designs' => 'Uspješno nadodani dizajni računa',
    'sent' => 'Poslano',
    'vat_number' => 'OIB',
    'timesheets' => 'Vremenik',
    'payment_title' => 'Unesite svoju adresu računa i informacije kreditne kartice',
    'payment_cvv' => '*Ovo je 3-4 znamenkasti broj na poleđini vaše kartice',
    'payment_footer1' => '*Adresa računa mora se poklapati s adresom na kreditnoj kartici.',
    'payment_footer2' => '*Molimo kliknite "PLATI ODMAH" samo jednom - transakcija može izvoditi i do 1 minute.',
    'id_number' => 'ID broj',
    'white_label_link' => 'Bijela oznaka',
    'white_label_header' => 'Bijela oznaka',
    'bought_white_label' => 'Uspješno je omogućena licenca za bijele oznake',
    'white_labeled' => 'Označeno bijelom oznakom',
    'restore' => 'Obnovi',
    'restore_invoice' => 'Obnovi račun',
    'restore_quote' => 'Obnovi narudžbu',
    'restore_client' => 'Obnovi klijenta',
    'restore_credit' => 'Obnovi kredit',
    'restore_payment' => 'Obnovi uplatu',
    'restored_invoice' => 'Uspješno obnovljen račun',
    'restored_quote' => 'Uspješno obnovljena ponuda',
    'restored_client' => 'Uspješno obnovljen  klijent',
    'restored_payment' => 'Uspješno obnovljena uplata',
    'restored_credit' => 'Uspješno obnovljen kredit',
    'reason_for_canceling' => 'Pomozite nam unaprijediti web mjesto informacijom zašto odlazite.',
    'discount_percent' => 'Postotak',
    'discount_amount' => 'Iznos',
    'invoice_history' => 'Povijest računa',
    'quote_history' => 'Povijest ponude',
    'current_version' => 'Trenutna verzija',
    'select_version' => 'Izaberi inačicu',
    'view_history' => 'Pregled povijesti',
    'edit_payment' => 'Uredi uplatu',
    'updated_payment' => 'Uspješno ažurirana uplata',
    'deleted' => 'Obrisano',
    'restore_user' => 'Obnovi korisnika',
    'restored_user' => 'Uspješno obnovljen korisnik',
    'show_deleted_users' => 'Prikaži obrisane korisnike',
    'email_templates' => 'Predlošci e-pošte',
    'invoice_email' => 'E-pošta računa',
    'payment_email' => 'E-pošta uplate',
    'quote_email' => 'E-pošta ponude',
    'reset_all' => 'Resetiraj sve',
    'approve' => 'Odobri',
    'token_billing_type_id' => 'Token naplata',
    'token_billing_help' => 'Store payment details with WePay, Stripe, Braintree or GoCardless.',
    'token_billing_1' => 'Onemogućeno',
    'token_billing_2' => 'Opt-in - odabir je prikazan ali nije selektiran',
    'token_billing_3' => 'Opt-out - odabir je prikazan i selektiran',
    'token_billing_4' => 'Uvijek',
    'token_billing_checkbox' => 'Pohrani detalje kreditne kartice',
    'view_in_gateway' => 'View in :gateway',
    'use_card_on_file' => 'Use Card on File',
    'edit_payment_details' => 'Uredi detalje plaćanja',
    'token_billing' => 'Pohrani detalje kartice',
    'token_billing_secure' => 'The data is stored securely by :link',
    'support' => 'Podrška',
    'contact_information' => 'Kontaktne informacije',
    '256_encryption' => '256-bitna enkripcija',
    'amount_due' => 'Dospjeli iznos',
    'billing_address' => 'Adresa računa',
    'billing_method' => 'Metoda naplate',
    'order_overview' => 'Pregled narudžbe',
    'match_address' => '*Adresa se mora poklapati s adresom kreditne kartice.',
    'click_once' => '*Molimo kliknite "PLATI ODMAH" samo jednom - transakcija može izvoditi i do 1 minute.',
    'invoice_footer' => 'Podnožje računa',
    'save_as_default_footer' => 'Pohrani kao zadano podnožje',
    'token_management' => 'Upravljanje tokenima',
    'tokens' => 'Tokeni',
    'add_token' => 'Dodaj token',
    'show_deleted_tokens' => 'Prikaži obrisane tokene',
    'deleted_token' => 'Uspješno obrisan token',
    'created_token' => 'Uspješno kreiran token',
    'updated_token' => 'Uspješno ažuriran token',
    'edit_token' => 'Uredi token',
    'delete_token' => 'Obriši token',
    'token' => 'Token',
    'add_gateway' => 'Dodaj usmjernik',
    'delete_gateway' => 'Obriši usmjernik',
    'edit_gateway' => 'Uredi usmjernik',
    'updated_gateway' => 'Uspješno ažuriran usmjernik',
    'created_gateway' => 'Uspješno kreiran usmjernik',
    'deleted_gateway' => 'Uspješno obrisan usmjernik',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Kreditna kartica',
    'change_password' => 'Promijeni zaporku',
    'current_password' => 'Trenutna zaporka',
    'new_password' => 'Nova zaporka',
    'confirm_password' => 'Potvrdi zaporku',
    'password_error_incorrect' => 'Trenutna zaporka nije ispravna.',
    'password_error_invalid' => 'Nova zaporka je neispravna.',
    'updated_password' => 'Uspješno ažurirana zaporka',
    'api_tokens' => 'API tokeni',
    'users_and_tokens' => 'Korisnici & tokeni',
    'account_login' => 'Korisnička prijava',
    'recover_password' => 'Obnovite vašu zaporku',
    'forgot_password' => 'Zaboravili ste zaporku?',
    'email_address' => 'Adresa e-pošte',
    'lets_go' => 'Krenimo',
    'password_recovery' => 'Obnova zaporke',
    'send_email' => 'Slanje e-pošte',
    'set_password' => 'Postava zaporke',
    'converted' => 'Konvertirano',
    'email_approved' => 'Pošalji mi e-poštu kada je ponuda <b>odobrena</b>',
    'notification_quote_approved_subject' => 'Quote :invoice je odobrena od strane :client',
    'notification_quote_approved' => 'Slijedeći klijent  :client je odobrio ponudu :invoice iznosa :amount.',
    'resend_confirmation' => 'Ponovite potvrdnu e-poštu',
    'confirmation_resent' => 'E-pošta za potvdu je ponovo poslana',
    'gateway_help_42' => ':link za prijavu na BitPay.<br/>Bilješka: koristite tradicionalni API ključ, umjesto API tokena.',
    'payment_type_credit_card' => 'Kreditna kartica',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Baza znanja',
    'partial' => 'Partial/Deposit',
    'partial_remaining' => ':partial od :balance',
    'more_fields' => 'Više polja',
    'less_fields' => 'Manje polja',
    'client_name' => 'Klijent',
    'pdf_settings' => 'PDF postavke',
    'product_settings' => 'Postavke proizvoda',
    'auto_wrap' => 'Auto formatiranje stavke',
    'duplicate_post' => 'Pozor: prethodna stranica je poslana dvaput. Drugo slanje će biti ignorirano.',
    'view_documentation' => 'Pregled dokumentacije',
    'app_title' => 'Slobodno fakturiranje otvorenim kodom.',
    'app_description' => 'Invoice Ninja je slobodno rješenje otvorenog koda za fakturiranje i upravljanje klijentima. Pomoću Invoice Ninje možete jednostavno izrađivati i slati kreativne račune sa bilo kojeg uređaja koji ima pristup Internetu. Vaši klijenti mogu ispisivati račune, preuzeti ih kao pdf datoteke i čak vam platiti online unutar istog sustava.',
    'rows' => 'redaka',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Poddomena',
    'provide_name_or_email' => 'Unesite ime ili email',
    'charts_and_reports' => 'Karte & Izvješća',
    'chart' => 'Karte',
    'report' => 'Izvješća',
    'group_by' => 'Grupiraj po',
    'paid' => 'Plaćeno',
    'enable_report' => 'Izvješće',
    'enable_chart' => 'Karta',
    'totals' => 'Zbrojevi',
    'run' => 'Pokreni',
    'export' => 'Izvoz',
    'documentation' => 'Dokumentacija',
    'zapier' => 'Zapier',
    'recurring' => 'Redovni',
    'last_invoice_sent' => 'Zadni račun poslan :date',
    'processed_updates' => 'Uspješno dovršeno ažuriranje',
    'tasks' => 'Zadaci',
    'new_task' => 'Novi zadatak',
    'start_time' => 'Početno vrijeme',
    'created_task' => 'Uspješno kreiran zadatak',
    'updated_task' => 'Uspješno ažuriran zadatak',
    'edit_task' => 'Uredi zadatak',
    'clone_task' => 'Kloniraj zadatak',
    'archive_task' => 'Arhiviraj zadatak',
    'restore_task' => 'Obnovi zadatak',
    'delete_task' => 'Obriši zadatak',
    'stop_task' => 'Završi zadatak',
    'time' => 'Vrijeme',
    'start' => 'Početak',
    'stop' => 'Završetak',
    'now' => 'Sada',
    'timer' => 'Štoperica',
    'manual' => 'Ručno',
    'date_and_time' => 'Datum & vrijeme',
    'second' => 'sekunda',
    'seconds' => 'sekunde',
    'minute' => 'minuta',
    'minutes' => 'minute',
    'hour' => 'sat',
    'hours' => 'sati',
    'task_details' => 'Detalji zadatka',
    'duration' => 'Trajanje',
    'time_log' => 'Dnevnik vremena',
    'end_time' => 'Završno vrijeme',
    'end' => 'Kraj',
    'invoiced' => 'Fakturirano',
    'logged' => 'Logirano',
    'running' => 'Pokrenuto',
    'task_error_multiple_clients' => 'Zadaci ne mogu pripadati različitim klijentima',
    'task_error_running' => 'Molimo najprije dovršite izvođenje zadatka',
    'task_error_invoiced' => 'Zadaci su več fakturirani',
    'restored_task' => 'Uspješno obnovljen zadatak',
    'archived_task' => 'Uspješno arhiviran zadatak',
    'archived_tasks' => 'Uspješno arhivirano :count zadataka',
    'deleted_task' => 'Uspješno obrisan zadatak',
    'deleted_tasks' => 'Uspješno obrisano :count zadataka',
    'create_task' => 'Kreiraj zadatak',
    'stopped_task' => 'Uspješno završen zadatak',
    'invoice_task' => 'Fakturiraj zadatak',
    'invoice_labels' => 'Oznake računa',
    'prefix' => 'Prefiks',
    'counter' => 'Brojač',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link za prijavu na Dwolla',
    'partial_value' => 'Mora biti veće od nula i manje od zbroja',
    'more_actions' => 'Više akcija',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Nadogradite odmah!',
    'pro_plan_feature1' => 'Kreirajte neograničeno klijenata',
    'pro_plan_feature2' => 'Pristup na 10 izvrsnih dizajna računa',
    'pro_plan_feature3' => 'Prilagođeni URL - "VašBrand.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Uklonite "Created by Invoice Ninja"',
    'pro_plan_feature5' => 'Višekorisnički pristup & praćenje aktivnosti',
    'pro_plan_feature6' => 'Kreiranje ponuda & predračuna',
    'pro_plan_feature7' => 'Prilagodba naslova polja računa & numeriranje',
    'pro_plan_feature8' => 'Opcija za privitak PDFa na e-poštu klijenta',
    'resume' => 'Nastavi',
    'break_duration' => 'Prekini',
    'edit_details' => 'Uredi detalje',
    'work' => 'Rad',
    'timezone_unset' => 'Molimo :link za postavu vaše vremenske zone',
    'click_here' => 'kliknite ovdje',
    'email_receipt' => 'Pošalji e-poštom račun klijentu',
    'created_payment_emailed_client' => 'Uspješno kreirana uplata i poslana klijentu e-poštom',
    'add_company' => 'Dodaj poduzeće',
    'untitled' => 'Bez naslova',
    'new_company' => 'Novo poduzeće',
    'associated_accounts' => 'Uspješno povezani računi',
    'unlinked_account' => 'Uspješno razdvojeni računi',
    'login' => 'Prijava',
    'or' => 'ili',
    'email_error' => 'Došlo je do problema pri slanju e-pošte',
    'confirm_recurring_timing' => 'Bilješka: e-pošta je poslana na početku sata.',
    'confirm_recurring_timing_not_sent' => 'Note: invoices are created at the start of the hour.',
    'payment_terms_help' => 'Sets the default <b>invoice due date</b>',
    'unlink_account' => 'Razdvoji račune',
    'unlink' => 'Razdvoji',
    'show_address' => 'Prikaži adrese',
    'show_address_help' => 'Zahtijevaj od klijenta adresu za fakture',
    'update_address' => 'Ažuriraj adresu',
    'update_address_help' => 'Ažuriraj adresu klijenta uz osigurane detalje',
    'times' => 'Vremena',
    'set_now' => 'Postavi na sada',
    'dark_mode' => 'Tamni prikaz',
    'dark_mode_help' => 'Koristi tamnu pozadinu za bočnu navigaciju',
    'add_to_invoice' => 'Dodaj računu :invoice',
    'create_new_invoice' => 'Kreiraj novi račun',
    'task_errors' => 'Molimo korigirajte preklopna vremena',
    'from' => 'Šalje',
    'to' => 'Prima',
    'font_size' => 'Veličina fonta',
    'primary_color' => 'Primarna boja',
    'secondary_color' => 'Sekundarna boja',
    'customize_design' => 'Prilagodi dizajn',
    'content' => 'Sadržaj',
    'styles' => 'Stilovi',
    'defaults' => 'Zadano',
    'margins' => 'Margine',
    'header' => 'Zaglavlje',
    'footer' => 'Podnožje',
    'custom' => 'Prilagođeno',
    'invoice_to' => 'Fakturiraj na',
    'invoice_no' => 'Broj računa',
    'quote_no' => 'Ponuda #',
    'recent_payments' => 'Nedavne uplate',
    'outstanding' => 'Dospijeva',
    'manage_companies' => 'Upravljanje poduzećima',
    'total_revenue' => 'Ukupni prihod',
    'current_user' => 'Trenutni korisnik',
    'new_recurring_invoice' => 'Novi redovni račun',
    'recurring_invoice' => 'Redovni račun',
    'new_recurring_quote' => 'Nova ponavljajuća ponuda',
    'recurring_quote' => 'Ponavljajuća ponuda',
    'recurring_too_soon' => 'Prerano je za kreiranje novog redovnog računa, na rasporedu je za :date',
    'created_by_invoice' => 'Kreiran od :invoice',
    'primary_user' => 'Primarni korisnik',
    'help' => 'Pomoć',
    'customize_help' => '<p>We use :pdfmake_link to define the invoice designs declaratively. The pdfmake :playground_link provides a great way to see the library in action.</p>
                        <p>If you need help figuring something out post a question to our :forum_link with the design you\'re using.</p>',
    'playground' => 'playground',
    'support_forum' => 'support forum',
    'invoice_due_date' => 'Datum valute',
    'quote_due_date' => 'Vrijedi do',
    'valid_until' => 'Vrijedi do',
    'reset_terms' => 'Resetiraj uvjete',
    'reset_footer' => 'Resetiraj podnožje',
    'invoice_sent' => ':count invoice sent',
    'invoices_sent' => ':count invoices sent',
    'status_draft' => 'Nacrt',
    'status_sent' => 'Poslano',
    'status_viewed' => 'Pregledano',
    'status_partial' => 'Parcijalno',
    'status_paid' => 'Plaćeno',
    'status_unpaid' => 'Neplaćeno',
    'status_all' => 'Sve',
    'show_line_item_tax' => 'Prikaži <b>poreze u liniji stavke</b>',
    'iframe_url' => 'Web mjesto',
    'iframe_url_help1' => 'Kopiraj slijedeći kod na stranicu svog web mjesta.',
    'iframe_url_help2' => 'Možete testirati mogućnost klikom na \'Pogledaj kao primatelj\' za račun.',
    'auto_bill' => 'Auto račun',
    'military_time' => '24 satno vrijeme',
    'last_sent' => 'Zadnje poslano',
    'reminder_emails' => 'E-pošta podsjetnik',
    'quote_reminder_emails' => 'Podsjetnik za ponudu',
    'templates_and_reminders' => 'Predlošci & podsjetnici',
    'subject' => 'Naslov',
    'body' => 'Tijelo',
    'first_reminder' => 'Prvi podsjetnik',
    'second_reminder' => 'Drugi podsjetnik',
    'third_reminder' => 'Treći podsjetnik',
    'num_days_reminder' => 'Dana nakon isteka valute',
    'reminder_subject' => 'Podsjetnik: Račun :invoice od :account',
    'reset' => 'Resetiraj',
    'invoice_not_found' => 'Traženi račun nije dostupan',
    'referral_program' => 'Referentni progam',
    'referral_code' => 'Referentni URL',
    'last_sent_on' => 'Zadnje poslano :date',
    'page_expire' => 'Ova stranica će uskoro isteći, :click_here za nastavak rada',
    'upcoming_quotes' => 'Nadolazeće ponude',
    'expired_quotes' => 'Istekle ponude',
    'sign_up_using' => 'Prijavi se koristeći',
    'invalid_credentials' => 'Ove vjerodajnice se ne odgovaraju našim zapisima',
    'show_all_options' => 'Prkaži sve opcije',
    'user_details' => 'Detalji korisnika',
    'oneclick_login' => 'Povezani računi',
    'disable' => 'Onemogući',
    'invoice_quote_number' => 'Brojevi računa i ponuda',
    'invoice_charges' => 'Invoice Surcharges',
    'notification_invoice_bounced' => 'Nismo mogli dostaviti račun :invoice prema :contact.',
    'notification_invoice_bounced_subject' => 'Nije moguće dostaviti :invoice',
    'notification_quote_bounced' => 'Nismo mogli dostaviti ponudu :invoice prema :contact',
    'notification_quote_bounced_subject' => 'Nije moguće dostaviti ponudu :invoice',
    'custom_invoice_link' => 'Prilagođena poveznica računa',
    'total_invoiced' => 'Ukupno fakturirano',
    'open_balance' => 'Trenutno dugovanje',
    'verify_email' => 'Molimo posjetite poveznicu unutar potvrdne e-pošte računa kako bi potvrdili svoju adresu e-pošte.',
    'basic_settings' => 'Osnovne postavke',
    'pro' => 'Pro',
    'gateways' => 'Platni usmjernici',
    'next_send_on' => 'Pošalji slijedeći: :date',
    'no_longer_running' => 'Ovaj račun nije zakazan za slanje',
    'general_settings' => 'Opće postavke',
    'customize' => 'Prilagodi',
    'oneclick_login_help' => 'Spoji se na račun za prijavu bez zaporke',
    'referral_code_help' => 'Zaradite novac dijeleći našu aplikaciju online',
    'enable_with_stripe' => 'Omogući | Zahtijeva Stripe',
    'tax_settings' => 'Postavke poreza',
    'create_tax_rate' => 'Dodaj poreznu stopu',
    'updated_tax_rate' => 'Uspješno ažurirana porezna stopa',
    'created_tax_rate' => 'Uspješno kreirana porezna stopa',
    'edit_tax_rate' => 'Uredi poreznu stopu',
    'archive_tax_rate' => 'Arhiviraj poreznu stopu',
    'archived_tax_rate' => 'Uspješno arhivirana porezna stopa',
    'default_tax_rate_id' => 'Zadana porezna stopa',
    'tax_rate' => 'Porezna stopa',
    'recurring_hour' => 'Ponavljajući sat',
    'pattern' => 'Uzorak',
    'pattern_help_title' => 'Pomoć za uzorke',
    'pattern_help_1' => 'Kreirajte vlastiti izgled broja računa uređivanjem paterna.',
    'pattern_help_2' => 'Dostupne varijable:',
    'pattern_help_3' => 'Na primjer, :example bi bilo pretvoreno u :value',
    'see_options' => 'Pogledaj opcije',
    'invoice_counter' => 'Brojač računa',
    'quote_counter' => 'Brojač ponuda',
    'type' => 'Tip',
    'activity_1' => ':user kreirao klijenta :client',
    'activity_2' => ':user arhivirao klijenta :client',
    'activity_3' => ':user obrisao klijenta :client',
    'activity_4' => ':user kreirao račun :invoice',
    'activity_5' => ':user ažurirao račun :invoice',
    'activity_6' => ':user poslao e-poštom račun :invoice za :contact',
    'activity_7' => ':contact pregledao račun :invoice',
    'activity_8' => ':user arhivirao račun :invoice',
    'activity_9' => ':user obrisao račun :invoce',
    'activity_10' => ':contact upisao uplatu :payment za :invoice',
    'activity_11' => ':user ažurirao uplatu :payment',
    'activity_12' => ':user ahivirao uplatu :payment',
    'activity_13' => ':user obrisao uplatu :payment',
    'activity_14' => ':user upisao :credit kredit',
    'activity_15' => ':user ažurirao :credit kredit',
    'activity_16' => ':user arhivirao :credit kredit',
    'activity_17' => ':user obrisao :credit kredit',
    'activity_18' => ':user kreirao ponudu :quote',
    'activity_19' => ':user ažurirao ponudu :quote',
    'activity_20' => ':user poslao e-poštom ponudu :quote za :contact',
    'activity_21' => ':contact pregledao ponudu :quote',
    'activity_22' => ':user arhivirao ponudu :quote',
    'activity_23' => ':user obrisao ponudu :quote',
    'activity_24' => ':user obnovio ponudu :quote',
    'activity_25' => ':user obnovio račun :invoice',
    'activity_26' => ':user obnovio klijenta :client',
    'activity_27' => ':user obnovio uplatu :payment',
    'activity_28' => ':user obnovio :credit kredit',
    'activity_29' => ':contact odobrio ponudu :quote',
    'activity_30' => ':user created vendor :vendor',
    'activity_31' => ':user archived vendor :vendor',
    'activity_32' => ':user deleted vendor :vendor',
    'activity_33' => ':user restored vendor :vendor',
    'activity_34' => ':user kreirao trošak :expense',
    'activity_35' => ':user archived expense :expense',
    'activity_36' => ':user deleted expense :expense',
    'activity_37' => ':user restored expense :expense',
    'activity_42' => ':user created task :task',
    'activity_43' => ':user updated task :task',
    'activity_44' => ':user archived task :task',
    'activity_45' => ':user deleted task :task',
    'activity_46' => ':user restored task :task',
    'activity_47' => ':user updated expense :expense',
    'activity_48' => 'Korisnik :user je ažurirao radni nalog :ticket',
    'activity_49' => 'Korisnik :user je zatvorio radni nalog :ticket',
    'activity_50' => 'Korisnik :user je spojio radni nalog :ticket',
    'activity_51' => 'Korisnik :user je razdijelio radni nalog :ticket',
    'activity_52' => 'Kontakt :contact je otvorio radni nalog :ticket',
    'activity_53' => 'Kontakt :contact je ponovno otvorio radni nalog :ticket',
    'activity_54' => 'Korisnik :user je ponovno otvorio radni nalog :ticket',
    'activity_55' => 'Kontakt :contact je odgovorio na radni nalog :ticket',
    'activity_56' => 'Korisnik :user je pregledao radni nalog :ticket',

    'payment' => 'Uplata',
    'system' => 'Sustav',
    'signature' => 'Potpis e-pošte',
    'default_messages' => 'Zadane poruke',
    'quote_terms' => 'Uvjeti ponude',
    'default_quote_terms' => 'Zadani uvjeti ponude',
    'default_invoice_terms' => 'Zadani uvjeti računa',
    'default_invoice_footer' => 'Zadano podnožje računa',
    'quote_footer' => 'Podnožje ponude',
    'free' => 'Slobodan',
    'quote_is_approved' => 'Successfully approved',
    'apply_credit' => 'Primjeni kredit',
    'system_settings' => 'Postavke sustava',
    'archive_token' => 'Arhiviraj token',
    'archived_token' => 'Uspješno arhiviran token',
    'archive_user' => 'Arhiviraj korisnika',
    'archived_user' => 'Uspješno arhiviran korisnik',
    'archive_account_gateway' => 'Arhiviraj usmjernik',
    'archived_account_gateway' => 'Uspješno arhiviran usmjernik',
    'archive_recurring_invoice' => 'Arhiviraj redoviti račun',
    'archived_recurring_invoice' => 'Uspješno arhiviran redoviti račun',
    'delete_recurring_invoice' => 'Obriši redoviti račun',
    'deleted_recurring_invoice' => 'Uspješno obrisan redoviti račun',
    'restore_recurring_invoice' => 'Obnovi redoviti račun',
    'restored_recurring_invoice' => 'Uspješno obnovljen redoviti račun',
    'archive_recurring_quote' => 'Arhiviraj ponavljajuću ponudi',
    'archived_recurring_quote' => 'Ponavljajuća ponuda je uspješno arhivirana',
    'delete_recurring_quote' => 'Obriši ponavljajuću ponudu',
    'deleted_recurring_quote' => 'Ponavljajuća ponuda je uspješno obrisana',
    'restore_recurring_quote' => 'Obnovi ponavljajuću ponudu',
    'restored_recurring_quote' => 'Ponavljajuća ponuda je uspješno obnovljena',
    'archived' => 'Arhivirano',
    'untitled_account' => 'Neimenovano poduzeće',
    'before' => 'Prije',
    'after' => 'Poslije',
    'reset_terms_help' => 'Resetiraj na zadane postavke računa',
    'reset_footer_help' => 'Resetiraj na zadane postavke podnožja',
    'export_data' => 'Izvezi podatke',
    'user' => 'Korisnik',
    'country' => 'Zemlja',
    'include' => 'Uključi',
    'logo_too_large' => 'Vaš logo je :size, za bolju PDF izvedbu preporučujemo otpremu slikovne datoteke manje od 200KB',
    'import_freshbooks' => 'Uvezi iz FreshBooks',
    'import_data' => 'Uvezi podatke',
    'source' => 'Izvor',
    'csv' => 'CSV',
    'client_file' => 'Klijentska datoteka',
    'invoice_file' => 'Datoteka računa',
    'task_file' => 'Datoteka zadataka',
    'no_mapper' => 'Nema ispravnog mapiranja za datoteku',
    'invalid_csv_header' => 'Neispravno CSV zaglavlje',
    'client_portal' => 'Klijentski portal',
    'admin' => 'Administracija',
    'disabled' => 'Onemogućeno',
    'show_archived_users' => 'Prikaži arhivirane korisnike',
    'notes' => 'Bilješke',
    'invoice_will_create' => 'račun će biti kreiran',
    'invoices_will_create' => 'računi će biti kreirani',
    'failed_to_import' => 'The following records failed to import, they either already exist or are missing required fields.',
    'publishable_key' => 'Objavljivi ključ',
    'secret_key' => 'Tajni ključ',
    'missing_publishable_key' => 'Postavite vap Stripe objavljivi ključ za poboljšani proces odjave',
    'email_design' => 'Dizajn e-pošte',
    'due_by' => 'Valuta do :date',
    'enable_email_markup' => 'Omogući markup',
    'enable_email_markup_help' => 'Olakšajte svojim klijentima plaćanje dodavanjem schema.org markupa vašoj e-pošti.',
    'template_help_title' => 'Pomoć za predloške',
    'template_help_1' => 'Dostupne varijable:',
    'email_design_id' => 'Stil e-pošte',
    'email_design_help' => 'Make your emails look more professional with HTML layouts.',
    'plain' => 'Obično',
    'light' => 'Svijetlo',
    'dark' => 'Tamno',
    'industry_help' => 'Koristi se za usporedbe između prosjeka poduzeća sličnih veličina i djelatnosti.',
    'subdomain_help' => 'Postavi poddomenu ili prikazujte račune na vlastitoj web stranici.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Odredite prefiks ili koristite prilagođeni uzorak za dinamično postavljanje brojeva računa.',
    'quote_number_help' => 'Odredite prefiks ili koristite prilagođeni uzorak za dinamično postavljanje brojeva ponuda.',
    'custom_client_fields_helps' => 'Add a field when creating a client and optionally display the label and value on the PDF.',
    'custom_account_fields_helps' => 'Dodajte oznaku i vrijednost na sekciju sa detaljima poduzeža na PDFu.',
    'custom_invoice_fields_helps' => 'Add a field when creating an invoice and optionally display the label and value on the PDF.',
    'custom_invoice_charges_helps' => 'Add a field when creating an invoice and include the charge in the invoice subtotals.',
    'token_expired' => 'Validacijski token je istekao. Molimo pokušajte ponovo.',
    'invoice_link' => 'Poveznica računa',
    'button_confirmation_message' => 'Kliknite za potvrdu vaše adrese e-pošte.',
    'confirm' => 'Odobri',
    'email_preferences' => 'Postavke e-pošte',
    'created_invoices' => 'Uspješno kreirano :count računa',
    'next_invoice_number' => 'Slijedeći broj računa je :number.',
    'next_quote_number' => 'Slijedeći broj ponude je :number.',
    'days_before' => 'dana prije',
    'days_after' => 'dana poslije',
    'field_due_date' => 'datum valute',
    'field_invoice_date' => 'datum računa',
    'schedule' => 'Raspored',
    'email_designs' => 'Dizajn e-pošte',
    'assigned_when_sent' => 'Dodijeljeno pri slanju',
    'white_label_purchase_link' => 'Kupite licencu bijele oznake',
    'expense' => 'Trošak',
    'expenses' => 'Troškovi',
    'new_expense' => 'Novi trošak',
    'enter_expense' => 'Unesi trošak',
    'vendors' => 'Dobavljači',
    'new_vendor' => 'Novi dobavljač',
    'payment_terms_net' => 'čisto',
    'vendor' => 'Dobavljač',
    'edit_vendor' => 'Uredi dobavljača',
    'archive_vendor' => 'Arhiviraj dobavljača',
    'delete_vendor' => 'Obriši dobavljača',
    'view_vendor' => 'Pregledaj dobavljača',
    'deleted_expense' => 'Uspješno obrisan trošak',
    'archived_expense' => 'Uspješno arhiviran trošak',
    'deleted_expenses' => 'Uspješno obrisan trošak',
    'archived_expenses' => 'Uspješno arhivirani troškovi',
    'expense_amount' => 'Iznos troškova',
    'expense_balance' => 'Stanje troškova',
    'expense_date' => 'Datum troška',
    'expense_should_be_invoiced' => 'Treba li fakturirati ovaj trošak?',
    'public_notes' => 'Javne bilješke',
    'invoice_amount' => 'Iznos računa',
    'exchange_rate' => 'Tečaj',
    'yes' => 'Da',
    'no' => 'Ne',
    'should_be_invoiced' => 'Treba biti fakturiran',
    'view_expense' => 'Pregled troškova # :expense',
    'edit_expense' => 'Uredi trošak',
    'archive_expense' => 'Arhiviraj trošak',
    'delete_expense' => 'Obriši trošak',
    'view_expense_num' => 'Trošak # :expense',
    'updated_expense' => 'Uspješno ažuriran trošak',
    'created_expense' => 'Uspješno kreiran trošak',
    'enter_expense' => 'Unesi trošak',
    'view' => 'Pregled',
    'restore_expense' => 'Obnovi trošak',
    'invoice_expense' => 'Trošak računa',
    'expense_error_multiple_clients' => 'Troškovi ne mogu pripadati različitim klijentima',
    'expense_error_invoiced' => 'Trošak je već fakturiran',
    'convert_currency' => 'Konvertiraj valutu',
    'num_days' => 'Broj dana',
    'create_payment_term' => 'Kreiraj uvjete plaćanja',
    'edit_payment_terms' => 'Uredi uvjet plaćanja',
    'edit_payment_term' => 'Uredi uvjete plaćanja',
    'archive_payment_term' => 'Arhiviraj uvjet plaćanje',
    'recurring_due_dates' => 'Datumi dospjeća redovnih računa',
    'recurring_due_date_help' => '<p>Automatski postavlja datume dospjeća za račune.</p>
        <p>Računi unutar mjesečnog ili godišnjeg ciklusa postavljeni da dospijevaju na dan ili prije dana na koji su kreirani biti će dospjeli slijedeći mjesec. Računi postavljeni da dospjevaju na 29. ili 30. u mjesecu a koji nemaju taj dan biti će dospjeli zadnji dan u mjesecu.</p>
        <p>Računi unutar tjednog ciklusa postavljeni da dospjevaju na dan u tjednu kada su kreirani dospijevati će slijedeći tjedan.</p>
        <p>Na primjer:</p>
        <ul>
          <li>Danas je 15., datum dospijeća je 1. u mjesecu. Datum dospijeća je izgledno 1. slijedećeg mjeseca.</li>
          <li>Danas je 15., datum dospijeća je zadnji dan u mjesecu. Datum dospijeća je zadnji dan u ovom mjesecu.
</li>
          <li>Danas je 15, datum dospjeća je 15. u mjesedu. Datum dospijeća će biti 15 dan  <strong>slijedećeg</strong> mjeseca.
</li>
          <li>Danas je petak, datum dospijeća je prvi slijedeći petak. Datum dospijeća je prvi slijedeći petak, a ne današnji petak.
</li>
        </ul>',
    'due' => 'Dospjelo',
    'next_due_on' => 'Dospijeva slijedeće :date',
    'use_client_terms' => 'Koristi uvjete klijenta',
    'day_of_month' => ':ordinal dan u mjesecu',
    'last_day_of_month' => 'Zadnji dan u mjesecu',
    'day_of_week_after' => ':ordinal :day nakon',
    'sunday' => 'Nedjelja',
    'monday' => 'Ponedjeljak',
    'tuesday' => 'Utorak',
    'wednesday' => 'Srijeda',
    'thursday' => 'Četvrtak',
    'friday' => 'Petak',
    'saturday' => 'Subota',
    'header_font_id' => 'Font zaglavlja',
    'body_font_id' => 'Font tijela',
    'color_font_help' => 'Bilješka: primarna boja i fontovi su također korišteni u klijentskom portalu i prilagođenom dizajnu e-pošte',
    'live_preview' => 'Pretpregled uživo',
    'invalid_mail_config' => 'Nije moguće poslati e-poštu, molim provjerite da li su vaše postavke e-pošte ispravne.',
    'invoice_message_button' => 'Za pregled vašeg račun iznosa :amount, kliknite na donju tipku.',
    'quote_message_button' => 'Za pregled vaše ponude iznosa :amount, kliknite donju tipku.',
    'payment_message_button' => 'Hvala vam na vašoj uplati od :amount.',
    'payment_type_direct_debit' => 'Direktni dug',
    'bank_accounts' => 'Kreditne kartice & banke',
    'add_bank_account' => 'Dodajte bankovni račun',
    'setup_account' => 'Postava računa',
    'import_expenses' => 'Uvezi troškove',
    'bank_id' => 'Banka',
    'integration_type' => 'Tip integracije',
    'updated_bank_account' => 'Uspješno ažuriran bankovni račun',
    'edit_bank_account' => 'Uredi bankovni račun',
    'archive_bank_account' => 'Arhiviraj bankovni račun',
    'archived_bank_account' => 'Uspješno arhiviran bankovni račun',
    'created_bank_account' => 'Uspješno kreiran bankovni račun',
    'validate_bank_account' => 'Provjeri bankovni račun',
    'bank_password_help' => 'Bilješka: vaša zaporka je sigurno odaslana i nikada nije pohranjivana na našim serverima.',
    'bank_password_warning' => 'Pozor: vaša zaporka je mogla biti odaslana kao običan tekst, razmotrite omogućavanje HTTPSa.',
    'username' => 'Korisničko ime',
    'account_number' => 'Broj računa',
    'account_name' => 'Ime računa',
    'bank_account_error' => 'Failed to retrieve account details, please check your credentials.',
    'status_approved' => 'Odobreno',
    'quote_settings' => 'Postavke ponude',
    'auto_convert_quote' => 'Auto Convert',
    'auto_convert_quote_help' => 'Automatski konvertirajte ponudu u račun nakon što je odobrena od strane klijenta.',
    'validate' => 'Validiraj',
    'info' => 'Info',
    'imported_expenses' => 'Uspješno kreirano :count_vendors dobavljača i :count_expenses troškova',
    'iframe_url_help3' => 'Bilješka: Ukoliko planirate prihvaćati kreditne kartice, snažno preporučujemo omogućavanje HTTPS na vašem web mjestu.',
    'expense_error_multiple_currencies' => 'Troškovi ne mogu imati različite valute.',
    'expense_error_mismatch_currencies' => 'Valute klijenata se ne podudaraju sa valutama troškova.',
    'trello_roadmap' => 'Trello razvojna cesta',
    'header_footer' => 'Zaglavlje/Podnožje',
    'first_page' => 'First page',
    'all_pages' => 'All pages',
    'last_page' => 'Last page',
    'all_pages_header' => 'Prikaži zaglavlje na',
    'all_pages_footer' => 'Prikaži podnožje na',
    'invoice_currency' => 'Valuta računa',
    'enable_https' => 'Snažno preporučujemo korištenje HTTPS za prihvat detalja kreditnih kartica online.',
    'quote_issued_to' => 'Ponuda napravljena za',
    'show_currency_code' => 'Kod valute',
    'free_year_message' => 'Your account has been upgraded to the pro plan for one year at no cost.',
    'trial_message' => 'Vaš račun će primiti besplatni dvotjedni probni rok za naš pro plan.',
    'trial_footer' => 'Your free pro plan trial lasts :count more days, :link to upgrade now.',
    'trial_footer_last_day' => 'This is the last day of your free pro plan trial, :link to upgrade now.',
    'trial_call_to_action' => 'Pokreni besplatni probni rok',
    'trial_success' => 'Uspješno je omogućeno dva tjedna besplatnog probnog pro plan roka',
    'overdue' => 'Van valute',


    'white_label_text' => 'Purchase a ONE YEAR white label license for $:price to remove the Invoice Ninja branding from the invoice and client portal.',
    'user_email_footer' => 'To adjust your email notification settings please visit :link',
    'reset_password_footer' => 'If you did not request this password reset please email our support: :email',
    'limit_users' => 'Sorry, this will exceed the limit of :limit users',
    'more_designs_self_host_header' => 'Get 6 more invoice designs for just $:price',
    'old_browser' => 'Please use a :link',
    'newer_browser' => 'newer browser',
    'white_label_custom_css' => ':link for $:price to enable custom styling and help support our project.',
    'bank_accounts_help' => 'Connect a bank account to automatically import expenses and create vendors. Supports American Express and :link.',
    'us_banks' => '400+ US banks',

    'pro_plan_remove_logo' => ':link to remove the Invoice Ninja logo by joining the Pro Plan',
    'pro_plan_remove_logo_link' => 'Kliknite ovdje',
    'invitation_status_sent' => 'Poslano',
    'invitation_status_opened' => 'Otvoreno',
    'invitation_status_viewed' => 'Pregledano',
    'email_error_inactive_client' => 'Emails can not be sent to inactive clients',
    'email_error_inactive_contact' => 'Emails can not be sent to inactive contacts',
    'email_error_inactive_invoice' => 'Emails can not be sent to inactive invoices',
    'email_error_inactive_proposal' => 'Emails can not be sent to inactive proposals',
    'email_error_user_unregistered' => 'Please register your account to send emails',
    'email_error_user_unconfirmed' => 'Please confirm your account to send emails',
    'email_error_invalid_contact_email' => 'Invalid contact email
Nevažeći kontakt email',

    'navigation' => 'Navigacija',
    'list_invoices' => 'Izlistaj računa',
    'list_clients' => 'Izlistaj klijenata',
    'list_quotes' => 'Izlistaj ponuda',
    'list_tasks' => 'List Tasks',
    'list_expenses' => 'List Expenses',
    'list_recurring_invoices' => 'List Recurring Invoices',
    'list_payments' => 'List Payments',
    'list_credits' => 'List Credits',
    'tax_name' => 'Ime porezne stope',
    'report_settings' => 'Report Settings',
    'search_hotkey' => '(unesi / za pomoć)',

    'new_user' => 'Novi korisnik',
    'new_product' => 'Novi proizvod / usluga',
    'new_tax_rate' => 'Nova porezna stopa',
    'invoiced_amount' => 'Iznos računa',
    'invoice_item_fields' => 'Polja stavke računa',
    'custom_invoice_item_fields_help' => 'Add a field when creating an invoice item and display the label and value on the PDF.',
    'recurring_invoice_number' => 'Ponavljajući broj',
    'recurring_invoice_number_prefix_help' => 'Speciy a prefix to be added to the invoice number for recurring invoices.',

    // Client Passwords
    'enable_portal_password' => 'Password Protect Invoices',
    'enable_portal_password_help' => 'Allows you to set a password for each contact. If a password is set, the contact will be required to enter a password before viewing invoices.',
    'send_portal_password' => 'Generiraj automatski',
    'send_portal_password_help' => 'If no password is set, one will be generated and sent with the first invoice.',

    'expired' => 'Isteklo',
    'invalid_card_number' => 'The credit card number is not valid.',
    'invalid_expiry' => 'The expiration date is not valid.',
    'invalid_cvv' => 'The CVV is not valid.',
    'cost' => 'Cijena',
    'create_invoice_for_sample' => 'Note: create your first invoice to see a preview here.',

    // User Permissions
    'owner' => 'Vlasnik',
    'administrator' => 'Administrator',
    'administrator_help' => 'Allow user to manage users, change settings and modify all records',
    'user_create_all' => 'Create clients, invoices, etc.',
    'user_view_all' => 'View all clients, invoices, etc.',
    'user_edit_all' => 'Edit all clients, invoices, etc.',
    'gateway_help_20' => ':link to sign up for Sage Pay.',
    'gateway_help_21' => ':link to sign up for Sage Pay.',
    'partial_due' => 'Partial Due',
    'restore_vendor' => 'Restore Vendor',
    'restored_vendor' => 'Successfully restored vendor',
    'restored_expense' => 'Successfully restored expense',
    'permissions' => 'Permissions',
    'create_all_help' => 'Allow user to create and modify records',
    'view_all_help' => 'Allow user to view records they didn\'t create',
    'edit_all_help' => 'Allow user to modify records they didn\'t create',
    'view_payment' => 'Pregledaj uplatu',

    'january' => 'Siječanj',
    'february' => 'Veljača',
    'march' => 'Ožujak',
    'april' => 'Travanj',
    'may' => 'Svibanj',
    'june' => 'Lipanj',
    'july' => 'Srpanj',
    'august' => 'Kolovoz',
    'september' => 'Rujan',
    'october' => 'Listopad',
    'november' => 'Studeni',
    'december' => 'Prosinac',

    // Documents
    'documents_header' => 'Dokumenti:',
    'email_documents_header' => 'Dokumenti:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Dokumenti ponuda',
    'invoice_documents' => 'Dokumenti računa',
    'expense_documents' => 'Dokumenti troškova',
    'invoice_embed_documents' => 'Ugrađeni dokumenti',
    'invoice_embed_documents_help' => 'Ubaci dodane dokumente u račun.',
    'document_email_attachment' => 'Dodaj dokumente',
    'ubl_email_attachment' => 'Attach UBL',
    'download_documents' => 'Preuzmi dokumente (:size)',
    'documents_from_expenses' => 'Od troškova:',
    'dropzone_default_message' => 'Ispusti dokument ili klikni za prijenos',
    'dropzone_default_message_disabled' => 'Učitavanje onemogućeno',
    'dropzone_fallback_message' => 'Your browser does not support drag\'n\'drop file uploads.',
    'dropzone_fallback_text' => 'Please use the fallback form below to upload your files like in the olden days.',
    'dropzone_file_too_big' => 'Datoteka je prevelika ({{filesize}}MiB). Maksimalna veličina: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Nisu dozvoljene datoteke te vrste.',
    'dropzone_response_error' => 'Server responded with {{statusCode}} code.',
    'dropzone_cancel_upload' => 'Otkaži prijenos',
    'dropzone_cancel_upload_confirmation' => 'Jeste li sigurni da želite otkazati prijenos?',
    'dropzone_remove_file' => 'Ukloni datoteku',
    'documents' => 'Dokumenti',
    'document_date' => 'Datum dokumenta',
    'document_size' => 'Veličina',

    'enable_client_portal' => 'Klijentski Portal',
    'enable_client_portal_help' => 'Prikaži/sakrij klijentski portal.',
    'enable_client_portal_dashboard' => 'Nadzora ploča',
    'enable_client_portal_dashboard_help' => 'Prikaži/sakrij nadzornu ploču na klijentskom portalu.',

    // Plans
    'account_management' => 'Upravljanje računima',
    'plan_status' => 'Plan Status',

    'plan_upgrade' => 'Upgrade',
    'plan_change' => 'Change Plan',
    'pending_change_to' => 'Changes To',
    'plan_changes_to' => ':plan on :date',
    'plan_term_changes_to' => ':plan (:term) on :date',
    'cancel_plan_change' => 'Cancel Change',
    'plan' => 'Plan',
    'expires' => 'Expires',
    'renews' => 'Renews',
    'plan_expired' => ':plan Plan Expired',
    'trial_expired' => ':plan Plan Trial Ended',
    'never' => 'Never',
    'plan_free' => 'Free',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Self Hosted (White labeled)',
    'plan_free_self_hosted' => 'Self Hosted (Free)',
    'plan_trial' => 'Trial',
    'plan_term' => 'Term',
    'plan_term_monthly' => 'Monthly',
    'plan_term_yearly' => 'Yearly',
    'plan_term_month' => 'Month',
    'plan_term_year' => 'Year',
    'plan_price_monthly' => '$:price/Month',
    'plan_price_yearly' => '$:price/Year',
    'updated_plan' => 'Updated plan settings',
    'plan_paid' => 'Term Started',
    'plan_started' => 'Plan Started',
    'plan_expires' => 'Plan Expires',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'One year enrollment in the Invoice Ninja Pro Plan.',
    'pro_plan_month_description' => 'One month enrollment in the Invoice Ninja Pro Plan.',
    'enterprise_plan_product' => 'Enterprise Plan',
    'enterprise_plan_year_description' => 'One year enrollment in the Invoice Ninja Enterprise Plan.',
    'enterprise_plan_month_description' => 'One month enrollment in the Invoice Ninja Enterprise Plan.',
    'plan_credit_product' => 'Credit',
    'plan_credit_description' => 'Credit for unused time',
    'plan_pending_monthly' => 'Will switch to monthly on :date',
    'plan_refunded' => 'A refund has been issued.',

    'live_preview' => 'Pretpregled uživo',
    'page_size' => 'Page Size',
    'live_preview_disabled' => 'Live preview has been disabled to support selected font',
    'invoice_number_padding' => 'Padding',
    'preview' => 'Preview',
    'list_vendors' => 'List Vendors',
    'add_users_not_supported' => 'Upgrade to the Enterprise plan to add additional users to your account.',
    'enterprise_plan_features' => 'The Enterprise plan adds support for multiple users and file attachments, :link to see the full list of features.',
    'return_to_app' => 'Return To App',


    // Payment updates
    'refund_payment' => 'Refund Payment',
    'refund_max' => 'Max:',
    'refund' => 'Refund',
    'are_you_sure_refund' => 'Refund selected payments?',
    'status_pending' => 'Pending',
    'status_completed' => 'Dovršeno',
    'status_failed' => 'Failed',
    'status_partially_refunded' => 'Partially Refunded',
    'status_partially_refunded_amount' => ':amount Refunded',
    'status_refunded' => 'Refunded',
    'status_voided' => 'Cancelled',
    'refunded_payment' => 'Refunded Payment',
    'activity_39' => ':user cancelled a :payment_amount payment :payment',
    'activity_40' => ':user refunded :adjustment of a :payment_amount payment :payment',
    'card_expiration' => 'Exp:&nbsp:expires',

    'card_creditcardother' => 'Unknown',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accept US bank transfers',
    'stripe_ach_help' => 'ACH support must also be enabled in :link.',
    'ach_disabled' => 'Another gateway is already configured for direct debit.',

    'plaid' => 'Plaid',
    'client_id' => 'Client Id',
    'secret' => 'Secret',
    'public_key' => 'Public Key',
    'plaid_optional' => '(optional)',
    'plaid_environment_help' => 'When a Stripe test key is given, Plaid\'s development environment (tartan) will be used.',
    'other_providers' => 'Other Providers',
    'country_not_supported' => 'That country is not supported.',
    'invalid_routing_number' => 'The routing number is not valid.',
    'invalid_account_number' => 'The account number is not valid.',
    'account_number_mismatch' => 'The account numbers do not match.',
    'missing_account_holder_type' => 'Please select an individual or company account.',
    'missing_account_holder_name' => 'Please enter the account holder\'s name.',
    'routing_number' => 'Routing Number',
    'confirm_account_number' => 'Confirm Account Number',
    'individual_account' => 'Individual Account',
    'company_account' => 'Company Account',
    'account_holder_name' => 'Account Holder Name',
    'add_account' => 'Add Account',
    'payment_methods' => 'Payment Methods',
    'complete_verification' => 'Complete Verification',
    'verification_amount1' => 'Amount 1',
    'verification_amount2' => 'Amount 2',
    'payment_method_verified' => 'Verification completed successfully',
    'verification_failed' => 'Verification Failed',
    'remove_payment_method' => 'Remove Payment Method',
    'confirm_remove_payment_method' => 'Are you sure you want to remove this payment method?',
    'remove' => 'Remove',
    'payment_method_removed' => 'Removed payment method.',
    'bank_account_verification_help' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement. Please enter the amounts below.',
    'bank_account_verification_next_steps' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement.
        Once you have the amounts, come back to this payment methods page and click "Complete Verification" next to the account.',
    'unknown_bank' => 'Unknown Bank',
    'ach_verification_delay_help' => 'You will be able to use the account after completing verification. Verification usually takes 1-2 business days.',
    'add_credit_card' => 'Add Credit Card',
    'payment_method_added' => 'Added payment method.',
    'use_for_auto_bill' => 'Use For Autobill',
    'used_for_auto_bill' => 'Autobill Payment Method',
    'payment_method_set_as_default' => 'Set Autobill payment method.',
    'activity_41' => ':payment_amount payment (:payment) failed',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'You must :link.',
    'stripe_webhook_help_link_text' => 'add this URL as an endpoint at Stripe',
    'gocardless_webhook_help_link_text' => 'You must add this URL as an endpoint in GoCardless',
    'payment_method_error' => 'There was an error adding your payment methd. Please try again later.',
    'notification_invoice_payment_failed_subject' => 'Payment failed for Invoice :invoice',
    'notification_invoice_payment_failed' => 'A payment made by client :client towards Invoice :invoice failed. The payment has been marked as failed and :amount has been added to the client\'s balance.',
    'link_with_plaid' => 'Link Account Instantly with Plaid',
    'link_manually' => 'Link Manually',
    'secured_by_plaid' => 'Secured by Plaid',
    'plaid_linked_status' => 'Your bank account at :bank',
    'add_payment_method' => 'Add Payment Method',
    'account_holder_type' => 'Account Holder Type',
    'ach_authorization' => 'I authorize :company to use my bank account for future payments and, if necessary, electronically credit my account to correct erroneous debits. I understand that I may cancel this authorization at any time by removing the payment method or by contacting :email.',
    'ach_authorization_required' => 'You must consent to ACH transactions.',
    'off' => 'Off',
    'opt_in' => 'Opt-in',
    'opt_out' => 'Opt-out',
    'always' => 'Always',
    'opted_out' => 'Opted out',
    'opted_in' => 'Opted in',
    'manage_auto_bill' => 'Manage Auto-bill',
    'enabled' => 'Enabled',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Enable PayPal payments through BrainTree',
    'braintree_paypal_disabled_help' => 'The PayPal gateway is processing PayPal payments',
    'braintree_paypal_help' => 'You must also :link.',
    'braintree_paypal_help_link_text' => 'link PayPal to your BrainTree account',
    'token_billing_braintree_paypal' => 'Save payment details',
    'add_paypal_account' => 'Add PayPal Account',


    'no_payment_method_specified' => 'No payment method specified',
    'chart_type' => 'Chart Type',
    'format' => 'Format',
    'import_ofx' => 'Import OFX',
    'ofx_file' => 'OFX File',
    'ofx_parse_failed' => 'Failed to parse OFX file',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Sign up with WePay',
    'use_another_provider' => 'Use another provider',
    'company_name' => 'Company Name',
    'wepay_company_name_help' => 'This will appear on client\'s credit card statements.',
    'wepay_description_help' => 'The purpose of this account.',
    'wepay_tos_agree' => 'I agree to the :link.',
    'wepay_tos_link_text' => 'WePay Terms of Service',
    'resend_confirmation_email' => 'Resend Confirmation Email',
    'manage_account' => 'Manage Account',
    'action_required' => 'Action Required',
    'finish_setup' => 'Finish Setup',
    'created_wepay_confirmation_required' => 'Please check your email and confirm your email address with WePay.',
    'switch_to_wepay' => 'Switch to WePay',
    'switch' => 'Switch',
    'restore_account_gateway' => 'Restore Gateway',
    'restored_account_gateway' => 'Successfully restored gateway',
    'united_states' => 'United States',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Accept Debit Cards',
    'debit_cards' => 'Debit Cards',

    'warn_start_date_changed' => 'The next invoice will be sent on the new start date.',
    'warn_start_date_changed_not_sent' => 'The next invoice will be created on the new start date.',
    'original_start_date' => 'Original start date',
    'new_start_date' => 'New start date',
    'security' => 'Security',
    'see_whats_new' => 'See what\'s new in v:version',
    'wait_for_upload' => 'Please wait for the document upload to complete.',
    'upgrade_for_permissions' => 'Upgrade to our Enterprise plan to enable permissions.',
    'enable_second_tax_rate' => 'Enable specifying a <b>second tax rate</b>',
    'payment_file' => 'Payment File',
    'expense_file' => 'Expense File',
    'product_file' => 'Product File',
    'import_products' => 'Import Products',
    'products_will_create' => 'products will be created',
    'product_key' => 'Proizvod',
    'created_products' => 'Successfully created/updated :count product(s)',
    'export_help' => 'Use JSON if you plan to import the data into Invoice Ninja.<br/>The file includes clients, products, invoices, quotes and payments.',
    'selfhost_export_help' => '<br/>Savjetujemo da koristite mysqldump za stvaranje potpune sigurnosne kopije.',
    'JSON_file' => 'JSON File',

    'view_dashboard' => 'View Dashboard',
    'client_session_expired' => 'Session Expired',
    'client_session_expired_message' => 'Your session has expired. Please click the link in your email again.',

    'auto_bill_notification' => 'This invoice will automatically be billed to your :payment_method on file on :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'bankovni račun',
    'auto_bill_payment_method_credit_card' => 'credit card',
    'auto_bill_payment_method_paypal' => 'PayPal account',
    'auto_bill_notification_placeholder' => 'This invoice will automatically be billed to your credit card on file on the due date.',
    'payment_settings' => 'Payment Settings',

    'on_send_date' => 'On send date',
    'on_due_date' => 'On due date',
    'auto_bill_ach_date_help' => 'ACH will always auto bill on the due date.',
    'warn_change_auto_bill' => 'Due to NACHA rules, changes to this invoice may prevent ACH auto bill.',

    'bank_account' => 'Bank Account',
    'payment_processed_through_wepay' => 'ACH payments will be processed using WePay.',
    'wepay_payment_tos_agree' => 'I agree to the WePay :terms and :privacy_policy.',
    'privacy_policy' => 'Privacy Policy',
    'wepay_payment_tos_agree_required' => 'You must agree to the WePay Terms of Service and Privacy Policy.',
    'ach_email_prompt' => 'Please enter your email address:',
    'verification_pending' => 'Verification Pending',

    'update_font_cache' => 'Please force refresh the page to update the font cache.',
    'more_options' => 'More options',
    'credit_card' => 'Kreditna kartica',
    'bank_transfer' => 'Bankovni prijenos',
    'no_transaction_reference' => 'We did not recieve a payment transaction reference from the gateway.',
    'use_bank_on_file' => 'Use Bank on File',
    'auto_bill_email_message' => 'This invoice will automatically be billed to the payment method on file on the due date.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Added :date',
    'failed_remove_payment_method' => 'Failed to remove the payment method',
    'gateway_exists' => 'This gateway already exists',
    'manual_entry' => 'Ručni unos',
    'start_of_week' => 'First Day of the Week',

    // Frequencies
    'freq_inactive' => 'Inactive',
    'freq_daily' => 'Daily',
    'freq_weekly' => 'Weekly',
    'freq_biweekly' => 'Biweekly',
    'freq_two_weeks' => 'Two weeks',
    'freq_four_weeks' => 'Four weeks',
    'freq_monthly' => 'Monthly',
    'freq_three_months' => 'Three months',
    'freq_four_months' => 'Four months',
    'freq_six_months' => 'Six months',
    'freq_annually' => 'Annually',
    'freq_two_years' => 'Two years',

    // Payment types
    'payment_type_Apply Credit' => 'Apply Credit',
    'payment_type_Bank Transfer' => 'Bankovna uplata',
    'payment_type_Cash' => 'Gotovina',
    'payment_type_Debit' => 'Debit',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa Card',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Credit Card Other',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Check',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Accounting & Legal',
    'industry_Advertising' => 'Advertising',
    'industry_Aerospace' => 'Aerospace',
    'industry_Agriculture' => 'Agriculture',
    'industry_Automotive' => 'Automotive',
    'industry_Banking & Finance' => 'Banking & Finance',
    'industry_Biotechnology' => 'Biotechnology',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Business Services',
    'industry_Commodities & Chemicals' => 'Commodities & Chemicals',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Computers & Hightech',
    'industry_Defense' => 'Defense',
    'industry_Energy' => 'Energy',
    'industry_Entertainment' => 'Entertainment',
    'industry_Government' => 'Government',
    'industry_Healthcare & Life Sciences' => 'Healthcare & Life Sciences',
    'industry_Insurance' => 'Insurance',
    'industry_Manufacturing' => 'Manufacturing',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit & Higher Ed',
    'industry_Pharmaceuticals' => 'Pharmaceuticals',
    'industry_Professional Services & Consulting' => 'Professional Services & Consulting',
    'industry_Real Estate' => 'Real Estate',
    'industry_Restaurant & Catering' => 'Restaurant & Catering',
    'industry_Retail & Wholesale' => 'Retail & Wholesale',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Transportation',
    'industry_Travel & Luxury' => 'Travel & Luxury',
    'industry_Other' => 'Other',
    'industry_Photography' => 'Photography',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarctica',
    'country_Algeria' => 'Algeria',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua and Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australia',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgium',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosnia and Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brazil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgaria',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Belarus',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Cameroon',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cape Verde',
    'country_Cayman Islands' => 'Cayman Islands',
    'country_Central African Republic' => 'Central African Republic',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Chile',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan, Province of China',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'Congo, the Democratic Republic of the',
    'country_Cook Islands' => 'Cook Islands',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Hrvatska',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cyprus',
    'country_Czech Republic' => 'Czech Republic',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Denmark',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominican Republic',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Ethiopia',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estonia',
    'country_Faroe Islands' => 'Faroe Islands',
    'country_Falkland Islands (Malvinas)' => 'Falkland Islands (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia and the South Sandwich Islands',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'France',
    'country_French Guiana' => 'French Guiana',
    'country_French Polynesia' => 'French Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Germany',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Greece',
    'country_Greenland' => 'Greenland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Holy See (Vatican City State)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Hungary',
    'country_Iceland' => 'Iceland',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesia',
    'country_Iran, Islamic Republic of' => 'Iran, Islamic Republic of',
    'country_Iraq' => 'Iraq',
    'country_Ireland' => 'Ireland',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italy',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Lebanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Latvia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libya',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lithuania',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexico',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Netherlands',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'New Zealand',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norway',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua New Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Poland',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Romania',
    'country_Russian Federation' => 'Russian Federation',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Saudi Arabia',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakia',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Slovenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'South Africa',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spain',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sweden',
    'country_Switzerland' => 'Switzerland',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad and Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunisia',
    'country_Turkey' => 'Turkey',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia, the former Yugoslav Republic of',
    'country_Egypt' => 'Egypt',
    'country_United Kingdom' => 'United Kingdom',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'United States',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarian Republic of',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brazilian Portuguese',
    'lang_Croatian' => 'Hrvatski',
    'lang_Czech' => 'Czech',
    'lang_Danish' => 'Danish',
    'lang_Dutch' => 'Dutch',
    'lang_English' => 'English',
    'lang_French' => 'French',
    'lang_French - Canada' => 'French - Canada',
    'lang_German' => 'German',
    'lang_Italian' => 'Italian',
    'lang_Japanese' => 'Japanese',
    'lang_Lithuanian' => 'Lithuanian',
    'lang_Norwegian' => 'Norwegian',
    'lang_Polish' => 'Polish',
    'lang_Spanish' => 'Spanish',
    'lang_Spanish - Spain' => 'Spanish - Spain',
    'lang_Swedish' => 'Swedish',
    'lang_Albanian' => 'Albanian',
    'lang_Greek' => 'Greek',
    'lang_English - United Kingdom' => 'English - United Kingdom',
    'lang_English - Australia' => 'Engleski - Australija',
    'lang_Slovenian' => 'Slovenian',
    'lang_Finnish' => 'Finnish',
    'lang_Romanian' => 'Romanian',
    'lang_Turkish - Turkey' => 'Turkish - Turkey',
    'lang_Portuguese - Brazilian' => 'Portuguese - Brazilian',
    'lang_Portuguese - Portugal' => 'Portuguese - Portugal',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Makedonski',
    'lang_Chinese - Taiwan' => 'Kineski - Tajvan',
    'lang_Serbian' => 'Srpski',
    'lang_Bulgarian' => 'Bugarski',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Accounting & Legal',
    'industry_Advertising' => 'Advertising',
    'industry_Aerospace' => 'Aerospace',
    'industry_Agriculture' => 'Agriculture',
    'industry_Automotive' => 'Automotive',
    'industry_Banking & Finance' => 'Banking & Finance',
    'industry_Biotechnology' => 'Biotechnology',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Business Services',
    'industry_Commodities & Chemicals' => 'Commodities & Chemicals',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Computers & Hightech',
    'industry_Defense' => 'Defense',
    'industry_Energy' => 'Energy',
    'industry_Entertainment' => 'Entertainment',
    'industry_Government' => 'Government',
    'industry_Healthcare & Life Sciences' => 'Healthcare & Life Sciences',
    'industry_Insurance' => 'Insurance',
    'industry_Manufacturing' => 'Manufacturing',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit & Higher Ed',
    'industry_Pharmaceuticals' => 'Pharmaceuticals',
    'industry_Professional Services & Consulting' => 'Professional Services & Consulting',
    'industry_Real Estate' => 'Real Estate',
    'industry_Retail & Wholesale' => 'Retail & Wholesale',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Transportation',
    'industry_Travel & Luxury' => 'Travel & Luxury',
    'industry_Other' => 'Other',
    'industry_Photography' => 'Photography',

    'view_client_portal' => 'View client portal',
    'view_portal' => 'View Portal',
    'vendor_contacts' => 'Vendor Contacts',
    'all' => 'Svi',
    'selected' => 'Selected',
    'category' => 'Kategorija',
    'categories' => 'Kategorije',
    'new_expense_category' => 'Nova kategorija troškova',
    'edit_category' => 'Uredi kategoriju',
    'archive_expense_category' => 'Arhiviraj kategoriju',
    'expense_categories' => 'Kategorije troškova',
    'list_expense_categories' => 'Lista kategorija troškova',
    'updated_expense_category' => 'Successfully updated expense category',
    'created_expense_category' => 'Successfully created expense category',
    'archived_expense_category' => 'Successfully archived expense category',
    'archived_expense_categories' => 'Successfully archived :count expense category',
    'restore_expense_category' => 'Restore expense category',
    'restored_expense_category' => 'Successfully restored expense category',
    'apply_taxes' => 'Apply taxes',
    'min_to_max_users' => ':min to :max users',
    'max_users_reached' => 'The maximum number of users has been reached.',
    'buy_now_buttons' => 'Buy Now Buttons',
    'landing_page' => 'Landing Page',
    'payment_type' => 'Payment Type',
    'form' => 'Form',
    'link' => 'Link',
    'fields' => 'Fields',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Note: the client and invoice are created even if the transaction isn\'t completed.',
    'buy_now_buttons_disabled' => 'This feature requires that a product is created and a payment gateway is configured.',
    'enable_buy_now_buttons_help' => 'Enable support for buy now buttons',
    'changes_take_effect_immediately' => 'Note: changes take effect immediately',
    'wepay_account_description' => 'Payment gateway for Invoice Ninja',
    'payment_error_code' => 'There was an error processing your payment [:code]. Please try again later.',
    'standard_fees_apply' => 'Fee: 2.9%/1.2% [Credit Card/Bank Transfer] + $0.30 per successful charge.',
    'limit_import_rows' => 'Data needs to be imported in batches of :count rows or less',
    'error_title' => 'Something went wrong',
    'error_contact_text' => 'If you\'d like help please email us at :mailaddress',
    'no_undo' => 'Warning: this can\'t be undone.',
    'no_contact_selected' => 'Please select a contact',
    'no_client_selected' => 'Please select a client',

    'gateway_config_error' => 'It may help to set new passwords or generate new API keys.',
    'payment_type_on_file' => ':type on file',
    'invoice_for_client' => 'Invoice :invoice for :client',
    'intent_not_found' => 'Sorry, I\'m not sure what you\'re asking.',
    'intent_not_supported' => 'Sorry, I\'m not able to do that.',
    'client_not_found' => 'I wasn\'t able to find the client',
    'not_allowed' => 'Sorry, you don\'t have the needed permissions',
    'bot_emailed_invoice' => 'Your invoice has been sent.',
    'bot_emailed_notify_viewed' => 'I\'ll email you when it\'s viewed.',
    'bot_emailed_notify_paid' => 'I\'ll email you when it\'s paid.',
    'add_product_to_invoice' => 'Add 1 :product',
    'not_authorized' => 'You are not authorized',
    'bot_get_email' => 'Hi! (wave)<br/>Thanks for trying the Invoice Ninja Bot.<br/>You need to create a free account to use this bot.<br/>Send me your account email address to get started.',
    'bot_get_code' => 'Thanks! I\'ve sent a you an email with your security code.',
    'bot_welcome' => 'That\'s it, your account is verified.<br/>',
    'email_not_found' => 'I wasn\'t able to find an available account for :email',
    'invalid_code' => 'The code is not correct',
    'security_code_email_subject' => 'Security code for Invoice Ninja Bot',
    'security_code_email_line1' => 'This is your Invoice Ninja Bot security code.',
    'security_code_email_line2' => 'Note: it will expire in 10 minutes.',
    'bot_help_message' => 'I currently support:<br/>• Create\update\email an invoice<br/>• List products<br/>For example:<br/><i>invoice bob for 2 tickets, set the due date to next thursday and the discount to 10 percent</i>',
    'list_products' => 'List Products',

    'include_item_taxes_inline' => 'Include <b>line item taxes in line total</b>',
    'created_quotes' => 'Successfully created :count quotes(s)',
    'limited_gateways' => 'Note: we support one credit card gateway per company.',

    'warning' => 'Warning',
    'self-update' => 'Update',
    'update_invoiceninja_title' => 'Update Invoice Ninja',
    'update_invoiceninja_warning' => 'Before start upgrading Invoice Ninja create a backup of your database and files!',
    'update_invoiceninja_available' => 'A new version of Invoice Ninja is available.',
    'update_invoiceninja_unavailable' => 'No new version of Invoice Ninja available.',
    'update_invoiceninja_instructions' => 'Please install the new version <strong>:version</strong> by clicking the <em>Update now</em> button below. Afterwards you\'ll be redirected to the dashboard.',
    'update_invoiceninja_update_start' => 'Update now',
    'update_invoiceninja_download_start' => 'Download :version',
    'create_new' => 'Create New',

    'toggle_navigation' => 'Toggle Navigation',
    'toggle_history' => 'Toggle History',
    'unassigned' => 'Unassigned',
    'task' => 'Task',
    'contact_name' => 'Contact Name',
    'city_state_postal' => 'City/State/Postal',
    'custom_field' => 'Custom Field',
    'account_fields' => 'Company Fields',
    'facebook_and_twitter' => 'Facebook and Twitter',
    'facebook_and_twitter_help' => 'Follow our feeds to help support our project',
    'reseller_text' => 'Note: the white-label license is intended for personal use, please email us at :email if you\'d like to resell the app.',
    'unnamed_client' => 'Unnamed Client',

    'day' => 'Dan',
    'week' => 'Tjedan',
    'month' => 'Mjesec',
    'inactive_logout' => 'Odjavljeni ste zbog neaktivnosti',
    'reports' => 'Izvješća',
    'total_profit' => 'Ukupan profit',
    'total_expenses' => 'Ukupni troškovi',
    'quote_to' => 'Quote to',

    // Limits
    'limit' => 'Limit',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'No Limits',
    'set_limits' => 'Set :gateway_type Limits',
    'enable_min' => 'Enable min',
    'enable_max' => 'Enable max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'This invoice does not meet the limits for that payment type.',

    'date_range' => 'Raspon datuma',
    'raw' => 'Raw',
    'raw_html' => 'Raw HTML',
    'update' => 'Update',
    'invoice_fields_help' => 'Drag and drop fields to change their order and location',
    'new_category' => 'New Category',
    'restore_product' => 'Restore Product',
    'blank' => 'Blank',
    'invoice_save_error' => 'There was an error saving your invoice',
    'enable_recurring' => 'Enable Recurring',
    'disable_recurring' => 'Disable Recurring',
    'text' => 'Text',
    'expense_will_create' => 'expense will be created',
    'expenses_will_create' => 'expenses will be created',
    'created_expenses' => 'Successfully created :count expense(s)',

    'translate_app' => 'Help improve our translations with :link',
    'expense_category' => 'Expense Category',

    'go_ninja_pro' => 'Go Ninja Pro!',
    'go_enterprise' => 'Go Enterprise!',
    'upgrade_for_features' => 'Upgrade For More Features',
    'pay_annually_discount' => 'Pay annually for 10 months + 2 free!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'YourBrand.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Customize every aspect of your invoice!',
    'enterprise_upgrade_feature1' => 'Set permissions for multiple-users',
    'enterprise_upgrade_feature2' => 'Attach 3rd party files to invoices & expenses',
    'much_more' => 'Much More!',
    'all_pro_fetaures' => 'Plus all pro features!',

    'currency_symbol' => 'Symbol',
    'currency_code' => 'Code',

    'buy_license' => 'Buy License',
    'apply_license' => 'Apply License',
    'submit' => 'Submit',
    'white_label_license_key' => 'License Key',
    'invalid_white_label_license' => 'The white label license is not valid',
    'created_by' => 'Created by :name',
    'modules' => 'Modules',
    'financial_year_start' => 'First Month of the Year',
    'authentication' => 'Authentication',
    'checkbox' => 'Checkbox',
    'invoice_signature' => 'Signature',
    'show_accept_invoice_terms' => 'Invoice Terms Checkbox',
    'show_accept_invoice_terms_help' => 'Require client to confirm that they accept the invoice terms.',
    'show_accept_quote_terms' => 'Quote Terms Checkbox',
    'show_accept_quote_terms_help' => 'Require client to confirm that they accept the quote terms.',
    'require_invoice_signature' => 'Invoice Signature',
    'require_invoice_signature_help' => 'Require client to provide their signature.',
    'require_quote_signature' => 'Quote Signature',
    'require_quote_signature_help' => 'Require client to provide their signature.',
    'i_agree' => 'I Agree To The Terms',
    'sign_here' => 'Please sign here:',
    'authorization' => 'Authorization',
    'signed' => 'Signed',

    // BlueVine
    'bluevine_promo' => 'Get flexible business lines of credit and invoice factoring using BlueVine.',
    'bluevine_modal_label' => 'Sign up with BlueVine',
    'bluevine_modal_text' => '<h3>Fast funding for your business. No paperwork.</h3>
<ul><li>Flexible business lines of credit and invoice factoring.</li></ul>',
    'bluevine_create_account' => 'Create an account',
    'quote_types' => 'Get a quote for',
    'invoice_factoring' => 'Invoice factoring',
    'line_of_credit' => 'Line of credit',
    'fico_score' => 'Your FICO score',
    'business_inception' => 'Business Inception Date',
    'average_bank_balance' => 'Prosječno stanje na računu banke',
    'annual_revenue' => 'Annual revenue',
    'desired_credit_limit_factoring' => 'Desired invoice factoring limit',
    'desired_credit_limit_loc' => 'Desired line of credit limit',
    'desired_credit_limit' => 'Desired credit limit',
    'bluevine_credit_line_type_required' => 'You must choose at least one',
    'bluevine_field_required' => 'This field is required',
    'bluevine_unexpected_error' => 'An unexpected error occurred.',
    'bluevine_no_conditional_offer' => 'More information is required before getting a quote. Click continue below.',
    'bluevine_invoice_factoring' => 'Invoice Factoring',
    'bluevine_conditional_offer' => 'Conditional Offer',
    'bluevine_credit_line_amount' => 'Credit Line',
    'bluevine_advance_rate' => 'Advance Rate',
    'bluevine_weekly_discount_rate' => 'Weekly Discount Rate',
    'bluevine_minimum_fee_rate' => 'Minimum Fee',
    'bluevine_line_of_credit' => 'Line of Credit',
    'bluevine_interest_rate' => 'Interest Rate',
    'bluevine_weekly_draw_rate' => 'Weekly Draw Rate',
    'bluevine_continue' => 'Continue to BlueVine',
    'bluevine_completed' => 'BlueVine signup completed',

    'vendor_name' => 'Dobavljač',
    'entity_state' => 'Kanton',
    'client_created_at' => 'Datum kreiranja',
    'postmark_error' => 'There was a problem sending the email through Postmark: :link',
    'project' => 'Projekt',
    'projects' => 'Projekti',
    'new_project' => 'Novi projekt',
    'edit_project' => 'Uredi projekt',
    'archive_project' => 'Arhiviraj projekt',
    'list_projects' => 'Lista projekata',
    'updated_project' => 'Successfully updated project',
    'created_project' => 'Successfully created project',
    'archived_project' => 'Successfully archived project',
    'archived_projects' => 'Successfully archived :count projects',
    'restore_project' => 'Restore Project',
    'restored_project' => 'Successfully restored project',
    'delete_project' => 'Izbriši projekt',
    'deleted_project' => 'Successfully deleted project',
    'deleted_projects' => 'Successfully deleted :count projects',
    'delete_expense_category' => 'Izbriši kategoriju',
    'deleted_expense_category' => 'Successfully deleted category',
    'delete_product' => 'Izbriši proizvod',
    'deleted_product' => 'Successfully deleted product',
    'deleted_products' => 'Successfully deleted :count products',
    'restored_product' => 'Successfully restored product',
    'update_credit' => 'Ažuriraj kredit',
    'updated_credit' => 'Successfully updated credit',
    'edit_credit' => 'Uredi kredit',
    'realtime_preview' => 'Pregled uživo',
    'realtime_preview_help' => 'Pregled izmjena PDF-a u stvarnom vremenu na stranici faktura prilikom uređivanja fakture.<br/> Onemogućite ovo da biste poboljšali performanse prilikom uređivanja faktura.',
    'live_preview_help' => 'Display a live PDF preview on the invoice page.<br/>Disable this to improve performance when editing invoices.',
    'force_pdfjs_help' => 'Replace the built-in PDF viewer in :chrome_link and :firefox_link.<br/>Enable this if your browser is automatically downloading the PDF.',
    'force_pdfjs' => 'Prevent Download',
    'redirect_url' => 'Redirect URL',
    'redirect_url_help' => 'Optionally specify a URL to redirect to after a payment is entered.',
    'save_draft' => 'Save Draft',
    'refunded_credit_payment' => 'Refunded credit payment',
    'keyboard_shortcuts' => 'Keyboard Shortcuts',
    'toggle_menu' => 'Toggle Menu',
    'new_...' => 'New ...',
    'list_...' => 'List ...',
    'created_at' => 'Datum kreiranja',
    'contact_us' => 'Kontaktirajte nas',
    'user_guide' => 'User Guide',
    'promo_message' => 'Upgrade before :expires and get :amount OFF your first year of our Pro or Enterprise packages.',
    'discount_message' => ':amount off expires :expires',
    'mark_paid' => 'Označi uplatu',
    'marked_sent_invoice' => 'Successfully marked invoice sent',
    'marked_sent_invoices' => 'Successfully marked invoices sent',
    'invoice_name' => 'Račun',
    'product_will_create' => 'product will be created',
    'contact_us_response' => 'Thank you for your message! We\'ll try to respond as soon as possible.',
    'last_7_days' => 'Zadnjih 7 dana',
    'last_30_days' => 'Zadnjih 30 dana',
    'this_month' => 'Ovaj mjesec',
    'last_month' => 'Prošli mjesec',
    'current_quarter' => 'Tekuće tromjesječje',
    'last_quarter' => 'Prošlo tromjesječje',
    'last_year' => 'Prošla godina',
    'custom_range' => 'Prilagođeni Raspon',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Require',
    'license_expiring' => 'Note: Your license will expire in :count days, :link to renew it.',
    'security_confirmation' => 'Your email address has been confirmed.',
    'white_label_expired' => 'Your white label license has expired, please consider renewing it to help support our project.',
    'renew_license' => 'Renew License',
    'iphone_app_message' => 'Consider downloading our :link',
    'iphone_app' => 'iPhone app',
    'android_app' => 'Android app',
    'logged_in' => 'Prijavljen',
    'switch_to_primary' => 'Switch to your primary company (:name) to manage your plan.',
    'inclusive' => 'Inclusive',
    'exclusive' => 'Exclusive',
    'postal_city_state' => 'Postal/City/State',
    'phantomjs_help' => 'In certain cases the app uses :link_phantom to generate the PDF, install :link_docs to generate it locally.',
    'phantomjs_local' => 'Using local PhantomJS',
    'client_number' => 'Client Number',
    'client_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the client number.',
    'next_client_number' => 'The next client number is :number.',
    'generated_numbers' => 'Generirani brojevi',
    'notes_reminder1' => 'First Reminder',
    'notes_reminder2' => 'Second Reminder',
    'notes_reminder3' => 'Third Reminder',
    'notes_reminder4' => 'Podsjetnik',
    'bcc_email' => 'BCC Email',
    'tax_quote' => 'Tax Quote',
    'tax_invoice' => 'Tax Invoice',
    'emailed_invoices' => 'Successfully emailed invoices',
    'emailed_quotes' => 'Successfully emailed quotes',
    'website_url' => 'Website URL',
    'domain' => 'Domain',
    'domain_help' => 'Used in the client portal and when sending emails.',
    'domain_help_website' => 'Used when sending emails.',
    'import_invoices' => 'Uvoz računa',
    'new_report' => 'Novi izvještaj',
    'edit_report' => 'Uredi izvještaj',
    'columns' => 'Kolone',
    'filters' => 'Filteri',
    'sort_by' => 'Označi prema',
    'draft' => 'Skica',
    'unpaid' => 'Neplaćeno',
    'aging' => 'Izvan dospijeća',
    'age' => 'Dospijeće',
    'days' => 'Dani',
    'age_group_0' => '0 - 30 dana',
    'age_group_30' => '30 - 60 dana',
    'age_group_60' => '60 - 90 dana',
    'age_group_90' => '90 - 120 dana',
    'age_group_120' => '120+ dana',
    'invoice_details' => 'Detalji računa',
    'qty' => 'Količina',
    'profit_and_loss' => 'Profit i Trošak',
    'revenue' => 'Prihod',
    'profit' => 'Profit',
    'group_when_sorted' => 'Groupirano sortiranje',
    'group_dates_by' => 'Grupiraj datume prema',
    'year' => 'Godina',
    'view_statement' => 'Moje Izvješće',
    'statement' => 'Izvješće o stanju duga',
    'statement_date' => 'Datum izvješća',
    'mark_active' => 'Označi kao aktivno',
    'send_automatically' => 'Pošalji automatski',
    'initial_email' => 'Prvi Email',
    'invoice_not_emailed' => 'This invoice hasn\'t been emailed.',
    'quote_not_emailed' => 'This quote hasn\'t been emailed.',
    'sent_by' => 'Poslao :user',
    'recipients' => 'Primatelji',
    'save_as_default' => 'Spremi kao osnovno',
    'start_of_week_help' => 'Used by <b>date</b> selectors',
    'financial_year_start_help' => 'Used by <b>date range</b> selectors',
    'reports_help' => 'Shift + Click to sort by multple columns, Ctrl + Click to clear the grouping.',
    'this_year' => 'Ova godina',

    // Updated login screen
    'ninja_tagline' => 'Create. Send. Get Paid.',
    'login_or_existing' => 'Or login with a connected account.',
    'sign_up_now' => 'Sign Up Now',
    'not_a_member_yet' => 'Not a member yet?',
    'login_create_an_account' => 'Create an Account!',

    // New Client Portal styling
    'invoice_from' => 'Pregled uplata i otvorenih dugovanja :: OSMTHVPRH',
    'email_alias_message' => 'We require each company to have a unique email address.<br/>Consider using an alias. ie, email+label@example.com',
    'full_name' => 'Ime i prezime',
    'month_year' => 'MJESEC/GODINA',
    'valid_thru' => 'Vrijedi\do',

    'product_fields' => 'Product Fields',
    'custom_product_fields_help' => 'Add a field when creating a product or invoice and display the label and value on the PDF.',
    'freq_two_months' => 'Two months',
    'freq_yearly' => 'Annually',
    'profile' => 'Profile',
    'payment_type_help' => 'Sets the default <b>manual payment type</b>.',
    'industry_Construction' => 'Construction',
    'your_statement' => 'Your Statement',
    'statement_issued_to' => 'Statement issued to',
    'statement_to' => 'Statement to',
    'customize_options' => 'Customize options',
    'created_payment_term' => 'Successfully created payment term',
    'updated_payment_term' => 'Successfully updated payment term',
    'archived_payment_term' => 'Successfully archived payment term',
    'resend_invite' => 'Resend Invitation',
    'credit_created_by' => 'Credit created by payment :transaction_reference',
    'created_payment_and_credit' => 'Successfully created payment and credit',
    'created_payment_and_credit_emailed_client' => 'Successfully created payment and credit, and emailed client',
    'create_project' => 'Create project',
    'create_vendor' => 'Create vendor',
    'create_expense_category' => 'Create category',
    'pro_plan_reports' => ':link to enable reports by joining the Pro Plan',
    'mark_ready' => 'Mark Ready',

    'limits' => 'Limits',
    'fees' => 'Fees',
    'fee' => 'Fee',
    'set_limits_fees' => 'Set :gateway_type Limits/Fees',
    'fees_tax_help' => 'Enable line item taxes to set the fee tax rates.',
    'fees_sample' => 'The fee for a :amount invoice would be :total.',
    'discount_sample' => 'The discount for a :amount invoice would be :total.',
    'no_fees' => 'No Fees',
    'gateway_fees_disclaimer' => 'Warning: not all states/payment gateways allow adding fees, please review local laws/terms of service.',
    'percent' => 'Percent',
    'location' => 'Location',
    'line_item' => 'Line Item',
    'surcharge' => 'Surcharge',
    'location_first_surcharge' => 'Enabled - First surcharge',
    'location_second_surcharge' => 'Enabled - Second surcharge',
    'location_line_item' => 'Enabled - Line item',
    'online_payment_surcharge' => 'Online Payment Surcharge',
    'gateway_fees' => 'Gateway Fees',
    'fees_disabled' => 'Fees are disabled',
    'gateway_fees_help' => 'Automatically add an online payment surcharge/discount.',
    'gateway' => 'Gateway',
    'gateway_fee_change_warning' => 'If there are unpaid invoices with fees they need to be updated manually.',
    'fees_surcharge_help' => 'Customize surcharge :link.',
    'label_and_taxes' => 'label and taxes',
    'billable' => 'Billable',
    'logo_warning_too_large' => 'The image file is too large.',
    'logo_warning_fileinfo' => 'Warning: To support gifs the fileinfo PHP extension needs to be enabled.',
    'logo_warning_invalid' => 'There was a problem reading the image file, please try a different format.',

    'error_refresh_page' => 'An error occurred, please refresh the page and try again.',
    'data' => 'Data',
    'imported_settings' => 'Successfully imported settings',
    'reset_counter' => 'Resetiraj brojač',
    'next_reset' => 'Slijedeći reset',
    'reset_counter_help' => 'Automatically reset the invoice and quote counters.',
    'auto_bill_failed' => 'Auto-billing for invoice :invoice_number failed',
    'online_payment_discount' => 'Online Payment Discount',
    'created_new_company' => 'Successfully created new company',
    'fees_disabled_for_gateway' => 'Fees are disabled for this gateway.',
    'logout_and_delete' => 'Log Out/Delete Account',
    'tax_rate_type_help' => 'Inclusive tax rates adjust the line item cost when selected.<br/>Only exclusive tax rates can be used as a default.',
    'invoice_footer_help' => 'Use $pageNumber and $pageCount to display the page information.',
    'credit_note' => 'Credit Note',
    'credit_issued_to' => 'Credit issued to',
    'credit_to' => 'Credit to',
    'your_credit' => 'Your Credit',
    'credit_number' => 'Credit Number',
    'create_credit_note' => 'Create Credit Note',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Error: The gateways table has incorrect ids.',
    'purge_data' => 'Purge Data',
    'delete_data' => 'Delete Data',
    'purge_data_help' => 'Permanently delete all data but keep the account and settings.',
    'cancel_account_help' => 'Permanently delete the account along with all data and setting.',
    'purge_successful' => 'Successfully purged company data',
    'forbidden' => 'Forbidden',
    'purge_data_message' => 'Warning: This will permanently erase your data, there is no undo.',
    'contact_phone' => 'Contact Phone',
    'contact_email' => 'Contact Email',
    'reply_to_email' => 'Reply-To Email',
    'reply_to_email_help' => 'Specify the reply-to address for client emails.',
    'bcc_email_help' => 'Privately include this address with client emails.',
    'import_complete' => 'Your import has successfully completed.',
    'confirm_account_to_import' => 'Please confirm your account to import data.',
    'import_started' => 'Your import has started, we\'ll send you an email once it completes.',
    'listening' => 'Listening...',
    'microphone_help' => 'Say "new invoice for [client]" or "show me [client]\'s archived payments"',
    'voice_commands' => 'Voice Commands',
    'sample_commands' => 'Sample commands',
    'voice_commands_feedback' => 'We\'re actively working to improve this feature, if there\'s a command you\'d like us to support please email us at :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Money Order',
    'archived_products' => 'Successfully archived :count products',
    'recommend_on' => 'We recommend <b>enabling</b> this setting.',
    'recommend_off' => 'We recommend <b>disabling</b> this setting.',
    'notes_auto_billed' => 'Auto-billed',
    'surcharge_label' => 'Surcharge Label',
    'contact_fields' => 'Contact Fields',
    'custom_contact_fields_help' => 'Add a field when creating a contact and optionally display the label and value on the PDF.',
    'datatable_info' => 'Prikaz :start do :end od ukupno :total unosa',
    'credit_total' => 'Credit Total',
    'mark_billable' => 'Označi za plaćanje',
    'billed' => 'Billed',
    'company_variables' => 'Company Variables',
    'client_variables' => 'Client Variables',
    'invoice_variables' => 'Invoice Variables',
    'navigation_variables' => 'Navigation Variables',
    'custom_variables' => 'Custom Variables',
    'invalid_file' => 'Invalid file type',
    'add_documents_to_invoice' => 'Add documents to invoice',
    'mark_expense_paid' => 'Označi da je plaćeno',
    'white_label_license_error' => 'Failed to validate the license, check storage/logs/laravel-error.log for more details.',
    'plan_price' => 'Plan Price',
    'wrong_confirmation' => 'Incorrect confirmation code',
    'oauth_taken' => 'The account is already registered',
    'emailed_payment' => 'Successfully emailed payment',
    'email_payment' => 'Pošalji uplatu e-mailom',
    'invoiceplane_import' => 'Use :link to migrate your data from InvoicePlane.',
    'duplicate_expense_warning' => 'Warning: This :link may be a duplicate',
    'expense_link' => 'expense',
    'resume_task' => 'Resume Task',
    'resumed_task' => 'Successfully resumed task',
    'quote_design' => 'Quote Design',
    'default_design' => 'Standard Design',
    'custom_design1' => 'Custom Design 1',
    'custom_design2' => 'Custom Design 2',
    'custom_design3' => 'Custom Design 3',
    'empty' => 'Empty',
    'load_design' => 'Load Design',
    'accepted_card_logos' => 'Accepted Card Logos',
    'phantomjs_local_and_cloud' => 'Using local PhantomJS, falling back to phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Track payments using :link',
    'start_date_required' => 'The start date is required',
    'application_settings' => 'Application Settings',
    'database_connection' => 'Database Connection',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'Database',
    'test_connection' => 'Test connection',
    'from_name' => 'From Name',
    'from_address' => 'From Address',
    'port' => 'Port',
    'encryption' => 'Encryption',
    'mailgun_domain' => 'Mailgun Domain',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'Send test email',
    'select_label' => 'Select Label',
    'label' => 'Label',
    'service' => 'Service',
    'update_payment_details' => 'Uredi detalje plaćanja',
    'updated_payment_details' => 'Uspješno ažurirani detalji plaćanja',
    'update_credit_card' => 'Ažuriraj kreditnu karticu',
    'recurring_expenses' => 'Redovni troškovi',
    'recurring_expense' => 'Redovni trošak',
    'new_recurring_expense' => 'Novi redovni trošak',
    'edit_recurring_expense' => 'Uredi redovne troškove',
    'archive_recurring_expense' => 'Arhiviraj redovne troškove',
    'list_recurring_expense' => 'Lista redovnih troškova',
    'updated_recurring_expense' => 'Uspješno uređen redovni trošak',
    'created_recurring_expense' => 'Uspješno kreiran redovni trošak',
    'archived_recurring_expense' => 'Uspješno arhiviran redovni trošak',
    'restore_recurring_expense' => 'Restore Recurring Expense',
    'restored_recurring_expense' => 'Successfully restored recurring expense',
    'delete_recurring_expense' => 'Izbriši redovni trošak',
    'deleted_recurring_expense' => 'Uspješno izbrisan redovni trošak',
    'view_recurring_expense' => 'Pogledaj redovni trošak',
    'taxes_and_fees' => 'Porezi i naknade',
    'import_failed' => 'Import Failed',
    'recurring_prefix' => 'Recurring Prefix',
    'options' => 'Opcije',
    'credit_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the credit number for negative invoices.',
    'next_credit_number' => 'The next credit number is :number.',
    'padding_help' => 'The number of zero\'s to pad the number.',
    'import_warning_invalid_date' => 'Warning: The date format appears to be invalid.',
    'product_notes' => 'Bilješke proizvoda',
    'app_version' => 'App Version',
    'ofx_version' => 'OFX Version',
    'gateway_help_23' => ':link to get your Stripe API keys.',
    'error_app_key_set_to_default' => 'Error: APP_KEY is set to a default value, to update it backup your database and then run <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Charge Late Fee',
    'late_fee_amount' => 'Late Fee Amount',
    'late_fee_percent' => 'Late Fee Percent',
    'late_fee_added' => 'Late fee added on :date',
    'download_invoice' => 'Download Invoice',
    'download_quote' => 'Download Quote',
    'invoices_are_attached' => 'Your invoice PDFs are attached.',
    'downloaded_invoice' => 'An email will be sent with the invoice PDF',
    'downloaded_quote' => 'An email will be sent with the quote PDF',
    'downloaded_invoices' => 'An email will be sent with the invoice PDFs',
    'downloaded_quotes' => 'An email will be sent with the quote PDFs',
    'clone_expense' => 'Clone Expense',
    'default_documents' => 'Default Documents',
    'send_email_to_client' => 'Send email to the client',
    'refund_subject' => 'Refund Processed',
    'refund_body' => 'You have been processed a refund of :amount for invoice :invoice_number.',

    'currency_us_dollar' => 'US Dollar',
    'currency_british_pound' => 'British Pound',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danish Krone',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Swedish Krona',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduraška Lempira',
    'currency_surinamese_dollar' => 'Surinamski dolar',
    'currency_bahraini_dinar' => 'Bahreinski dinar',
    'currency_venezuelan_bolivars' => 'Venezuelski bolivari',
    'currency_south_korean_won' => 'Južnokorejski Won',
    'currency_moroccan_dirham' => 'Marokanski Dirham',
    'currency_jamaican_dollar' => 'Jamajčanski dolar',
    'currency_angolan_kwanza' => 'Angolska Kwanza',
    'currency_haitian_gourde' => 'Haitijski Gourde',
    'currency_zambian_kwacha' => 'Zambijska Kwacha',
    'currency_nepalese_rupee' => 'Nepalska Rupija',
    'currency_cfp_franc' => 'CFP Franak',
    'currency_mauritian_rupee' => 'Mauricijska Rupija',
    'currency_cape_verdean_escudo' => 'Zelenortski Escudo',
    'currency_kuwaiti_dinar' => 'Kuvajtski Dinar',
    'currency_algerian_dinar' => 'Alžirski Dinar',
    'currency_macedonian_denar' => 'Makedonski denar',
    'currency_fijian_dollar' => 'Fidžijski Dolar',
    'currency_bolivian_boliviano' => 'Bolivijski Boliviano',
    'currency_albanian_lek' => 'Albanski Lek',
    'currency_serbian_dinar' => 'Srpski dinar',
    'currency_lebanese_pound' => 'Libanonska Funta',
    'currency_armenian_dram' => 'Armenski Dram',
    'currency_azerbaijan_manat' => 'Azerbejdžanski Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosansko Hercegovačka Konvertibilna marka',
    'currency_belarusian_ruble' => 'Bjeloruski Rubalj',
    'currency_moldovan_leu' => 'Moldavski Lej',
    'currency_kazakhstani_tenge' => 'Kazahstanski Tenge',
    'currency_gibraltar_pound' => 'Gibraltarska Funta',

    'review_app_help' => 'We hope you\'re enjoying using the app.<br/>If you\'d consider :link we\'d greatly appreciate it!',
    'writing_a_review' => 'writing a review',

    'use_english_version' => 'Make sure to use the English version of the files.<br/>We use the column headers to match the fields.',
    'tax1' => 'First Tax',
    'tax2' => 'Second Tax',
    'fee_help' => 'Gateway fees are the costs charged for access to the financial networks that handle the processing of online payments.',
    'format_export' => 'Exporting format',
    'custom1' => 'First Custom',
    'custom2' => 'Second Custom',
    'contact_first_name' => 'Contact First Name',
    'contact_last_name' => 'Contact Last Name',
    'contact_custom1' => 'Contact First Custom',
    'contact_custom2' => 'Contact Second Custom',
    'currency' => 'Currency',
    'ofx_help' => 'To troubleshoot check for comments on :ofxhome_link and test with :ofxget_link.',
    'comments' => 'comments',

    'item_product' => 'Item Product',
    'item_notes' => 'Item Notes',
    'item_cost' => 'Jed. cijena',
    'item_quantity' => 'Item Quantity',
    'item_tax_rate' => 'Item Tax Rate',
    'item_tax_name' => 'Item Tax Name',
    'item_tax1' => 'Item Tax1',
    'item_tax2' => 'Item Tax2',

    'delete_company' => 'Delete Company',
    'delete_company_help' => 'Permanently delete the company along with all data and setting.',
    'delete_company_message' => 'Warning: This will permanently delete your company, there is no undo.',

    'applied_discount' => 'The coupon has been applied, the plan price has been reduced by :discount%.',
    'applied_free_year' => 'The coupon has been applied, your account has been upgraded to pro for one year.',

    'contact_us_help' => 'If you\'re reporting an error please include any relevant logs from storage/logs/laravel-error.log',
    'include_errors' => 'Include Errors',
    'include_errors_help' => 'Include :link from storage/logs/laravel-error.log',
    'recent_errors' => 'recent errors',
    'customer' => 'Customer',
    'customers' => 'Customers',
    'created_customer' => 'Successfully created customer',
    'created_customers' => 'Successfully created :count customers',

    'purge_details' => 'The data in your company (:account) has been successfully purged.',
    'deleted_company' => 'Successfully deleted company',
    'deleted_account' => 'Successfully canceled account',
    'deleted_company_details' => 'Your company (:account) has been successfully deleted.',
    'deleted_account_details' => 'Your account (:account) has been successfully deleted.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Accept Alipay',
    'enable_sofort' => 'Accept EU bank transfers',
    'stripe_alipay_help' => 'These gateways also need to be activated in :link.',
    'calendar' => 'Calendar',
    'pro_plan_calendar' => ':link to enable the calendar by joining the Pro Plan',

    'what_are_you_working_on' => 'Na čemu trenutno radite?',
    'time_tracker' => 'Time Tracker',
    'refresh' => 'Refresh',
    'filter_sort' => 'Filter/Sort',
    'no_description' => 'No Description',
    'time_tracker_login' => 'Time Tracker Login',
    'save_or_discard' => 'Save or discard your changes',
    'discard_changes' => 'Discard Changes',
    'tasks_not_enabled' => 'Tasks are not enabled.',
    'started_task' => 'Successfully started task',
    'create_client' => 'Create Client',

    'download_desktop_app' => 'Download the desktop app',
    'download_iphone_app' => 'Download the iPhone app',
    'download_android_app' => 'Download the Android app',
    'time_tracker_mobile_help' => 'Double tap a task to select it',
    'stopped' => 'Stopped',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
    'sort_field' => 'Sort By',
    'sort_direction' => 'Direction',
    'discard' => 'Discard',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'mins',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Clear',
    'warn_payment_gateway' => 'Note: accepting online payments requires a payment gateway, :link to add one.',
    'task_rate' => 'Satnica',
    'task_rate_help' => 'Postavite zadanu satnicu za zadatke.',
    'past_due' => 'Past Due',
    'document' => 'Document',
    'invoice_or_expense' => 'Invoice/Expense',
    'invoice_pdfs' => 'Invoice PDFs',
    'enable_sepa' => 'Accept SEPA',
    'enable_bitcoin' => 'Accept Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'By providing your IBAN and confirming this payment, you are authorizing :company and Stripe, our payment service provider, to send instructions to your bank to debit your account and your bank to debit your account in accordance with those instructions. You are entitled to a refund from your bank under the terms and conditions of your agreement with your bank. A refund must be claimed within 8 weeks starting from the date on which your account was debited.',
    'recover_license' => 'Recover License',
    'purchase' => 'Purchase',
    'recover' => 'Recover',
    'apply' => 'Apply',
    'recover_white_label_header' => 'Recover White Label License',
    'apply_white_label_header' => 'Apply White Label License',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Return to Invoice',
    'gateway_help_13' => 'To use ITN leave the PDT Key field blank.',
    'partial_due_date' => 'Partial Due Date',
    'task_fields' => 'Task Fields',
    'product_fields_help' => 'Drag and drop fields to change their order',
    'custom_value1' => 'Custom Value',
    'custom_value2' => 'Custom Value',
    'enable_two_factor' => 'Two-Factor Authentication',
    'enable_two_factor_help' => 'Use your phone to confirm your identity when logging in',
    'two_factor_setup' => 'Two-Factor Setup',
    'two_factor_setup_help' => 'Scan the bar code with a :link compatible app.',
    'one_time_password' => 'One Time Password',
    'set_phone_for_two_factor' => 'Set your mobile phone number as a backup to enable.',
    'enabled_two_factor' => 'Successfully enabled Two-Factor Authentication',
    'add_product' => 'Add Product',
    'email_will_be_sent_on' => 'Note: the email will be sent on :date.',
    'invoice_product' => 'Invoice Product',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Error: local storage is not available.',
    'your_password_reset_link' => 'Klikni na poveznicu za ponovno postavljanje lozinke',
    'subdomain_taken' => 'The subdomain is already in use',
    'client_login' => 'Pristup za članove',
    'converted_amount' => 'Converted Amount',
    'default' => 'Default',
    'shipping_address' => 'Shipping Address',
    'bllling_address' => 'Billing Address',
    'billing_address1' => 'Billing Street',
    'billing_address2' => 'Billing Apt/Suite',
    'billing_city' => 'Billing City',
    'billing_state' => 'Billing State/Province',
    'billing_postal_code' => 'Billing Postal Code',
    'billing_country' => 'Billing Country',
    'shipping_address1' => 'Shipping Street',
    'shipping_address2' => 'Shipping Apt/Suite',
    'shipping_city' => 'Shipping City',
    'shipping_state' => 'Shipping State/Province',
    'shipping_postal_code' => 'Shipping Postal Code',
    'shipping_country' => 'Shipping Country',
    'classify' => 'Classify',
    'show_shipping_address_help' => 'Require client to provide their shipping address',
    'ship_to_billing_address' => 'Ship to billing address',
    'delivery_note' => 'Delivery Note',
    'show_tasks_in_portal' => 'Show tasks in the client portal',
    'cancel_schedule' => 'Cancel Schedule',
    'scheduled_report' => 'Scheduled Report',
    'scheduled_report_help' => 'Email the :report report as :format to :email',
    'created_scheduled_report' => 'Successfully scheduled report',
    'deleted_scheduled_report' => 'Successfully canceled scheduled report',
    'scheduled_report_attached' => 'Your scheduled :type report is attached.',
    'scheduled_report_error' => 'Failed to create schedule report',
    'invalid_one_time_password' => 'Invalid one time password',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accept Apple Pay and Pay with Google',
    'requires_subdomain' => 'This payment type requires that a :link.',
    'subdomain_is_set' => 'subdomain is set',
    'verification_file' => 'Verification File',
    'verification_file_missing' => 'The verification file is needed to accept payments.',
    'apple_pay_domain' => 'Use <code>:domain</code> as the domain in :link.',
    'apple_pay_not_supported' => 'Sorry, Apple/Google Pay isn\'t supported',
    'optional_payment_methods' => 'Optional Payment Methods',
    'add_subscription' => 'Add Subscription',
    'target_url' => 'Target',
    'target_url_help' => 'When the selected event occurs the app will post the entity as JSON to the target URL.',
    'event' => 'Event',
    'subscription_event_1' => 'Created Client',
    'subscription_event_2' => 'Created Invoice',
    'subscription_event_3' => 'Created Quote',
    'subscription_event_4' => 'Created Payment',
    'subscription_event_5' => 'Created Vendor',
    'subscription_event_6' => 'Ažurirana ponuda',
    'subscription_event_7' => 'Obrisana ponuda',
    'subscription_event_8' => 'Ažurirani račun',
    'subscription_event_9' => 'Obrisani račun',
    'subscription_event_10' => 'Ažuriraj klijenta',
    'subscription_event_11' => 'Obriši klijenta',
    'subscription_event_12' => 'Obriši uplatu',
    'subscription_event_13' => 'Ažuriraj dobavljača',
    'subscription_event_14' => 'Obriši dobavljača',
    'subscription_event_15' => 'Kreiraj trošak',
    'subscription_event_16' => 'Ažuriraj trošak',
    'subscription_event_17' => 'Obriši trošak',
    'subscription_event_18' => 'Kreiraj zadatak',
    'subscription_event_19' => 'Ažuriraj zadatak',
    'subscription_event_20' => 'Obriši zadatak',
    'subscription_event_21' => 'Ponuda odobrena',
    'subscriptions' => 'Subscriptions',
    'updated_subscription' => 'Successfully updated subscription',
    'created_subscription' => 'Successfully created subscription',
    'edit_subscription' => 'Edit Subscription',
    'archive_subscription' => 'Archive Subscription',
    'archived_subscription' => 'Successfully archived subscription',
    'project_error_multiple_clients' => 'The projects can\'t belong to different clients',
    'invoice_project' => 'Invoice Project',
    'module_recurring_invoice' => 'Ponavljajući računi',
    'module_credit' => 'Credits',
    'module_quote' => 'Quotes & Proposals',
    'module_task' => 'Zadaci i projekti',
    'module_expense' => 'Troškovi i dobavljači',
    'module_ticket' => 'Radni nalozi',
    'reminders' => 'Podsjetnici',
    'send_client_reminders' => 'Send email reminders',
    'can_view_tasks' => 'Tasks are visible in the portal',
    'is_not_sent_reminders' => 'Reminders are not sent',
    'promotion_footer' => 'Your promotion will expire soon, :link to upgrade now.',
    'unable_to_delete_primary' => 'Note: to delete this company first delete all linked companies.',
    'please_register' => 'Please register your account',
    'processing_request' => 'Processing request',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Edit Times',
    'inclusive_taxes_help' => 'Uračunaj <b>porez u cijenu</b>',
    'inclusive_taxes_notice' => 'This setting can not be changed once an invoice has been created.',
    'inclusive_taxes_warning' => 'Warning: existing invoices will need to be resaved',
    'copy_shipping' => 'Copy Shipping',
    'copy_billing' => 'Copy Billing',
    'quote_has_expired' => 'The quote has expired, please contact the merchant.',
    'empty_table_footer' => 'Showing 0 to 0 of 0 entries',
    'do_not_trust' => 'Do not remember this device',
    'trust_for_30_days' => 'Trust for 30 days',
    'trust_forever' => 'Trust forever',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Ready to do',
    'in_progress' => 'U tijeku',
    'add_status' => 'Dodaj status',
    'archive_status' => 'Arhiviraj status',
    'new_status' => 'Novi status',
    'convert_products' => 'Convert Products',
    'convert_products_help' => 'Automatically convert product prices to the client\'s currency',
    'improve_client_portal_link' => 'Set a subdomain to shorten the client portal link.',
    'budgeted_hours' => 'Dogovoreno radnih sati',
    'progress' => 'Progres',
    'view_project' => 'Pogledaj Projekt',
    'summary' => 'Sažetak',
    'endless_reminder' => 'Endless Reminder',
    'signature_on_invoice_help' => 'Add the following code to show your client\'s signature on the PDF.',
    'signature_on_pdf' => 'Pokaži na PDF-u',
    'signature_on_pdf_help' => 'Show the client signature on the invoice/quote PDF.',
    'expired_white_label' => 'The white label license has expired',
    'return_to_login' => 'Povratak na stranicu za prijavu',
    'convert_products_tip' => 'Note: add a custom field named ":name" to see the exchange rate.',
    'amount_greater_than_balance' => 'The amount is greater than the invoice balance, a credit will be created with the remaining amount.',
    'custom_fields_tip' => 'Use <code>Label|Option1,Option2</code> to show a select box.',
    'client_information' => 'Osobni podaci',
    'updated_client_details' => 'Uspješno ažurirani osobni podaci',
    'auto' => 'Auto',
    'tax_amount' => 'Iznos poreza',
    'tax_paid' => 'Plaćeno poreza',
    'none' => 'None',
    'proposal_message_button' => 'To view your proposal for :amount, click the button below.',
    'proposal' => 'Prijedlog',
    'proposals' => 'Prijedlozi',
    'list_proposals' => 'Prikaži Ponude',
    'new_proposal' => 'Nova Ponuda',
    'edit_proposal' => 'Uredi Ponudu',
    'archive_proposal' => 'Arhiviraj Ponudu',
    'delete_proposal' => 'Obriši Ponudu',
    'created_proposal' => 'Ponuda je uspješno kreirana',
    'updated_proposal' => 'Ponuda je ažurirana',
    'archived_proposal' => 'Ponuda je arhivirana',
    'deleted_proposal' => 'Successfully archived proposal',
    'archived_proposals' => 'Successfully archived :count proposals',
    'deleted_proposals' => 'Successfully archived :count proposals',
    'restored_proposal' => 'Successfully restored proposal',
    'restore_proposal' => 'Vrati Ponudu',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'New Snippet',
    'edit_proposal_snippet' => 'Edit Snippet',
    'archive_proposal_snippet' => 'Archive Snippet',
    'delete_proposal_snippet' => 'Delete Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'Predložak',
    'templates' => 'Templates',
    'proposal_template' => 'Template',
    'proposal_templates' => 'Templates',
    'new_proposal_template' => 'New Template',
    'edit_proposal_template' => 'Edit Template',
    'archive_proposal_template' => 'Archive Template',
    'delete_proposal_template' => 'Delete Template',
    'created_proposal_template' => 'Successfully created template',
    'updated_proposal_template' => 'Successfully updated template',
    'archived_proposal_template' => 'Successfully archived template',
    'deleted_proposal_template' => 'Successfully archived template',
    'archived_proposal_templates' => 'Successfully archived :count templates',
    'deleted_proposal_templates' => 'Successfully archived :count templates',
    'restored_proposal_template' => 'Successfully restored template',
    'restore_proposal_template' => 'Restore Template',
    'proposal_category' => 'Kategorija',
    'proposal_categories' => 'Kategorije',
    'new_proposal_category' => 'Nova kategorija',
    'edit_proposal_category' => 'Uredi kategoriju',
    'archive_proposal_category' => 'Arhiviraj kategoriju',
    'delete_proposal_category' => 'Izbriši kategoriju',
    'created_proposal_category' => 'Kategorija uspješno kreirana',
    'updated_proposal_category' => 'Kategorija uspješno ažurirana',
    'archived_proposal_category' => 'Kategorija uspješno arhivirana',
    'deleted_proposal_category' => 'Kategorija uspješno arhivirana',
    'archived_proposal_categories' => 'Successfully archived :count categories',
    'deleted_proposal_categories' => 'Successfully archived :count categories',
    'restored_proposal_category' => 'Successfully restored category',
    'restore_proposal_category' => 'Restore Category',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Icon',
    'proposal_not_found' => 'The requested proposal is not available',
    'create_proposal_category' => 'Create category',
    'clone_proposal_template' => 'Clone Template',
    'proposal_email' => 'Proposal Email',
    'proposal_subject' => 'New proposal :number from :account',
    'proposal_message' => 'To view your proposal for :amount, click the link below.',
    'emailed_proposal' => 'Successfully emailed proposal',
    'load_template' => 'Load Template',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Add Image',
    'select_image' => 'Select Image',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Delete Image',
    'delete_image_help' => 'Warning: deleting the image will remove it from all proposals.',
    'amount_variable_help' => 'Note: the invoice $amount field will use the partial/deposit field if set otherwise it will use the invoice balance.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The refund will be recorded in the app but will NOT be processed by the payment gateway.',
    'email_address_changed' => 'Email address has been changed',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting to ZIP requires the GMP extension',
    'email_history' => 'Email History',
    'loading' => 'Loading',
    'no_messages_found' => 'No messages found',
    'processing' => 'Processing',
    'reactivate' => 'Reactivate',
    'reactivated_email' => 'The email address has been reactivated',
    'emails' => 'Emails',
    'opened' => 'Opened',
    'bounced' => 'Bounced',
    'total_sent' => 'Total Sent',
    'total_opened' => 'Total Opened',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'Email Clients',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Group',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'You\'ve received a new payment!',
    'slack_webhook_help' => 'Receive payment notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'Successfully accepted the latest terms of service',
    'invalid_url' => 'Invalid URL',
    'workflow_settings' => 'Workflow Settings',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automatically email recurring invoices when they are created.',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Automatically archive invoices when they are paid.',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Automatically archive quotes when they are converted.',
    'require_approve_quote' => 'Zahtijevaj odobrenje ponude',
    'require_approve_quote_help' => 'Zahtjevati od klijenta odobrenje ponuda.',
    'allow_approve_expired_quote' => 'Omogući odobrenje istekle ponude',
    'allow_approve_expired_quote_help' => 'Omogući klijentu da odobri istekle ponude.',
    'invoice_workflow' => 'Invoice Workflow',
    'quote_workflow' => 'Quote Workflow',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'All related records (invoices, tasks, expenses, documents, etc) will also be deleted.',
    'clone_product' => 'Clone Product',
    'item_details' => 'Item Details',
    'send_item_details_help' => 'Send the line item details to the payment gateway.',
    'view_proposal' => 'View Proposal',
    'view_in_portal' => 'View in Portal',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'vendor will be created',
    'vendors_will_create' => 'vendors will be created',
    'created_vendors' => 'Successfully created :count vendor(s)',
    'import_vendors' => 'Import Vendors',
    'company' => 'Company',
    'client_field' => 'Client Field',
    'contact_field' => 'Contact Field',
    'product_field' => 'Product Field',
    'task_field' => 'Task Field',
    'project_field' => 'Project Field',
    'expense_field' => 'Expense Field',
    'vendor_field' => 'Vendor Field',
    'company_field' => 'Company Field',
    'invoice_field' => 'Invoice Field',
    'invoice_surcharge' => 'Invoice Surcharge',
    'custom_task_fields_help' => 'Add a field when creating a task.',
    'custom_project_fields_help' => 'Add a field when creating a project.',
    'custom_expense_fields_help' => 'Add a field when creating an expense.',
    'custom_vendor_fields_help' => 'Add a field when creating a vendor.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Unpaid Invoice',
    'paid_invoice' => 'Paid Invoice',
    'unapproved_quote' => 'Unapproved Quote',
    'unapproved_proposal' => 'Unapproved Proposal',
    'autofills_city_state' => 'Auto-fills city/state',
    'no_match_found' => 'No match found',
    'password_strength' => 'Jačina lozinke',
    'strength_weak' => 'Slaba',
    'strength_good' => 'Dobra',
    'strength_strong' => 'Jaka',
    'mark' => 'Označi',
    'updated_task_status' => 'Successfully update task status',
    'background_image' => 'Pozadinska slika',
    'background_image_help' => 'Koristite :link za upravljanje vašim slikama. Savjetujemo korištenje malih datoteka.',
    'proposal_editor' => 'urednik prijedloga',
    'background' => 'Pozadina',
    'guide' => 'Vodič',
    'gateway_fee_item' => 'Gateway Fee Item',
    'gateway_fee_description' => 'Gateway Fee Surcharge',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Prikaži uplate',
    'show_aging' => 'Prikaži starenje',
    'reference' => 'Referenca',
    'amount_paid' => 'Plaćeni iznos',
    'send_notifications_for' => 'Pošalji obavjest za',
    'all_invoices' => 'Svi računi',
    'my_invoices' => 'Moji računi',
    'payment_reference' => 'Referenca transakcije',
    'maximum' => 'Maksimum',
    'sort' => 'Poredak',
    'refresh_complete' => 'Osvježavanje završeno',
    'please_enter_your_email' => 'Molimo upišite vašu email adresu',
    'please_enter_your_password' => 'Molimo upišite vašu zaporku',
    'please_enter_your_url' => 'Molimo unesite URL',
    'please_enter_a_product_key' => 'Molimo upišite šifru proizvoda',
    'an_error_occurred' => 'Dogodila se pogreška',
    'overview' => 'Pregled',
    'copied_to_clipboard' => 'Kopirao :value u međuspremnik',
    'error' => 'Greška',
    'could_not_launch' => 'Pokretanje nije uspjelo',
    'additional' => 'Dodatno',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email adresa je pogrešna',
    'items' => 'Stavke',
    'partial_deposit' => 'Djelomično/Depozit',
    'add_item' => 'Dodaj stavku',
    'total_amount' => 'Ukupan iznos',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Status računa',
    'click_plus_to_add_item' => 'Kliknite + za dodavanje stavke',
    'count_selected' => ':count odabrano',
    'dismiss' => 'Odbaci',
    'please_select_a_date' => 'Molimo odaberite datum',
    'please_select_a_client' => 'Molimo odaberite klijenta',
    'language' => 'Jezik',
    'updated_at' => 'Ažurirano',
    'please_enter_an_invoice_number' => 'Molimo upišite broj računa',
    'please_enter_a_quote_number' => 'Molimo upišite broj ponude',
    'clients_invoices' => 'računi od :client',
    'viewed' => 'Pregledano',
    'approved' => 'Odobreno',
    'invoice_status_1' => 'Nacrt',
    'invoice_status_2' => 'Poslano',
    'invoice_status_3' => 'Pregledano',
    'invoice_status_4' => 'Odobreno',
    'invoice_status_5' => 'Djelimično',
    'invoice_status_6' => 'Plaćeno',
    'marked_invoice_as_sent' => 'Račun je uspješno označen kao poslan',
    'please_enter_a_client_or_contact_name' => 'Molimo upišite ime klijenta ili kontakta',
    'restart_app_to_apply_change' => 'Ponovno pokrenite aplikaciju za primjenu promjena',
    'refresh_data' => 'Osvježi podatke',
    'blank_contact' => 'Prazan kontakt',
    'no_records_found' => 'Nije pronađen zapis',
    'industry' => 'Industrija',
    'size' => 'Veličina',
    'net' => 'Neto',
    'show_tasks' => 'Prikaži zadatke',
    'email_reminders' => 'Email podsjetnici',
    'reminder1' => 'Prvi podsjetnik',
    'reminder2' => 'Drugi podsjetnik',
    'reminder3' => 'Treći podsjetnik',
    'send' => 'Pošalji',
    'auto_billing' => 'Automatska naplata',
    'button' => 'Gumb',
    'more' => 'Više',
    'edit_recurring_invoice' => 'Uredi ponavljajući račun',
    'edit_recurring_quote' => 'Uredi ponavljajuću ponudu',
    'quote_status' => 'Status ponude',
    'please_select_an_invoice' => 'Molimo odaberite račun',
    'filtered_by' => 'Filtrirano po',
    'payment_status' => 'Status uplate',
    'payment_status_1' => 'U tijeku',
    'payment_status_2' => 'Poništeno',
    'payment_status_3' => 'Neuspješno',
    'payment_status_4' => 'Završeno',
    'payment_status_5' => 'Djelimični povrat',
    'payment_status_6' => 'Povrat',
    'send_receipt_to_client' => 'Pošalji račun klijentu',
    'refunded' => 'Povrat',
    'marked_quote_as_sent' => 'Ponuda je uspješno označena kao poslana',
    'custom_module_settings' => 'Postavke prilagođenog modula',
    'ticket' => 'Radni nalog',
    'tickets' => 'Radni nalozi',
    'ticket_number' => 'Radni nalog #',
    'new_ticket' => 'Novi radni nalog',
    'edit_ticket' => 'Uredi radni nalog',
    'view_ticket' => 'Pregledaj radni nalog',
    'archive_ticket' => 'Arhiviraj radni nalog ',
    'restore_ticket' => 'Vrati radni nalog',
    'delete_ticket' => 'Izbriši radni nalog',
    'archived_ticket' => 'Uspješno arhiviran radni nalog',
    'archived_tickets' => 'Uspješno arhivirani radni nalozi',
    'restored_ticket' => 'Uspješno vraćen radni nalog',
    'deleted_ticket' => 'Uspješno izbrisani radni nalog',
    'open' => 'Otvori',
    'new' => 'Novi',
    'closed' => 'Zatvoren',
    'reopened' => 'Ponovno otvoren',
    'priority' => 'Prioritet',
    'last_updated' => 'Zadnje ažuriranje',
    'comment' => 'Komentari',
    'tags' => 'Oznake',
    'linked_objects' => 'Povezani objekti',
    'low' => 'Nizak',
    'medium' => 'Srednji',
    'high' => 'Visok',
    'no_due_date' => 'Nije postavljen datum dospijeća',
    'assigned_to' => 'Dodijeljeno za',
    'reply' => 'Odgovori',
    'awaiting_reply' => 'Čeka odgovor',
    'ticket_close' => 'Zatvori radni nalog',
    'ticket_reopen' => 'Ponovno otvori radni nalog',
    'ticket_open' => 'Otvori radni nalog',
    'ticket_split' => 'Razdvoji radni nalog',
    'ticket_merge' => 'Spoji radni nalog',
    'ticket_update' => 'Ažuriraj radni nalog',
    'ticket_settings' => 'Postavke radnog naloga',
    'updated_ticket' => 'Radni nalog ažuriran',
    'mark_spam' => 'Označi kao Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Ime je zauzeto',
    'local_part_available' => 'Ime je dostupno',
    'local_part_invalid' => 'Nevažeće ime (samo alfanumerički, bez razmaka',
    'local_part_help' => 'Prilagodite lokalni dio dolazne e-pošte za podršku, tj. VASE_IME@support.invoiceninja.com',
    'from_name_help' => 'Od je prepoznatljivi pošiljatelj koji se prikazuje umjesto adrese e-pošte, tj. Centar za podršku',
    'local_part_placeholder' => 'VAŠE_IME',
    'from_name_placeholder' => 'Centar za podršku',
    'attachments' => 'Privitci',
    'client_upload' => 'Prenosi klijenta',
    'enable_client_upload_help' => 'Omogućite klijentima prijenos dokumenata/privitaka',
    'max_file_size_help' => 'Maksimalna veličina datoteke (KB) ograničena je vašim varijablama post_max_size i upload_max_filesize kako je postavljeno u vašoj PHP.INI datoteci',
    'max_file_size' => 'Maksimalna veličina datoteke',
    'mime_types' => 'MIME tipovi',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Popis dopuštenih vrsta MIME tipova, odvojeni zarezima. Za sve, ostavite prazno',
    'ticket_number_start_help' => 'Broj radnog naloga mora biti veći od zadnjeg broja naloga',
    'new_ticket_template_id' => 'Novi radni nalog',
    'new_ticket_autoresponder_help' => 'Odabir predloška poslat će automatski odgovor klijentu / kontaktu kada se kreira novi radni nalog',
    'update_ticket_template_id' => 'Ažurirani radni nalog',
    'update_ticket_autoresponder_help' => 'Odabir predloška poslat će automatski odgovor klijentu / kontaktu kada se radni nalog ažurira',
    'close_ticket_template_id' => 'Radni nalog zatvoren',
    'close_ticket_autoresponder_help' => 'Odabir predloška poslat će automatski odgovor klijentu / kontaktu kada se radni nalog zatvori',
    'default_priority' => 'Zadani prioritet',
    'alert_new_comment_id' => 'Novi komentar',
    'alert_comment_ticket_help' => 'Odabirom predloška poslat će se obavijest (agentu) kad se kreira komentar.',
    'alert_comment_ticket_email_help' => 'E-adrese odvojene zarezom na koje će se poslati skrivena kopija novog komentara.',
    'new_ticket_notification_list' => 'Dodatne obavijesti novog radnog naloga',
    'update_ticket_notification_list' => 'Dodatne obavijesti novog komentara ',
    'comma_separated_values' => 'admin@primjer.hr, korisnik@primjer.hr',
    'alert_ticket_assign_agent_id' => 'Dodjela radnog naloga',
    'alert_ticket_assign_agent_id_hel' => 'Odabirom predloška, obavijesti će biti poslana (agentu) kada je radni nalog dodijeljen.',
    'alert_ticket_assign_agent_id_notifications' => 'Dodatne obavijesti dodijeljenog radnog naloga',
    'alert_ticket_assign_agent_id_help' => 'E-adrese odvojene zarezom na koje će se poslati skrivena kopija obavijesti dodjele radnog naloga.',
    'alert_ticket_transfer_email_help' => 'E-adrese odvojene zarezom na koje će se poslati skrivena kopija prijenosa radnog naloga.',
    'alert_ticket_overdue_agent_id' => 'Randi nalog kasni',
    'alert_ticket_overdue_email' => 'Dodatne obavijesti o kašnjenju radnog naloga',
    'alert_ticket_overdue_email_help' => 'E-adrese odvojene zarezom na koje će se poslati skrivena kopija kašnjenja radnog naloga.',
    'alert_ticket_overdue_agent_id_help' => 'Odabirom predloška, obavijesti će biti poslana (agentu) kada je radni nalog kasni.',
    'ticket_master' => 'Vlasnik radnog naloga',
    'ticket_master_help' => 'Ima mogućnost dodjeljivanja i prijenosa radnih naloga. Dodijeljen kao zadani agent za sve ulaznice.',
    'default_agent' => 'Zadani agent',
    'default_agent_help' => 'Ako se odabere, automatski će se dodijeliti svim ulaznim radnim nalozima',
    'show_agent_details' => 'Prikaži detalje agenta u odgovorima',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Ukloni Avatar',
    'ticket_not_found' => 'Radni nalog nije pronađen',
    'add_template' => 'Dodaj Predložak',
    'ticket_template' => 'Predložak radnog naloga',
    'ticket_templates' => 'Predlošci radnih naloga',
    'updated_ticket_template' => 'Ažuriran predložak radnog naloga',
    'created_ticket_template' => 'Kreirani predložak radnog naloga',
    'archive_ticket_template' => 'Arhiviran predložak ranog naloga',
    'restore_ticket_template' => 'Vrati predložak radnog naloga',
    'archived_ticket_template' => 'Predložak uspješno arhiviran',
    'restored_ticket_template' => 'Uspješno obnovljen predložak',
    'close_reason' => 'Recite nam zašto zatvarate radni nalog',
    'reopen_reason' => 'Recite nam zašto ponovno otvarate radni nalog',
    'enter_ticket_message' => 'Unesite poruku kako biste ažurirali radni nalog',
    'show_hide_all' => 'Prikaži / sakrij sve',
    'subject_required' => 'Predmet je obavezan',
    'mobile_refresh_warning' => 'Ako koristite mobilnu aplikaciju, možda ćete morati izvršiti potpuno osvježavanje.',
    'enable_proposals_for_background' => 'Za učitavanje pozadinske slike :link za omogućavanje modula prijedloga.',
    'ticket_assignment' => 'Radni nalog :ticket_number dodijeljen je agentu :agent',
    'ticket_contact_reply' => 'Radni nalog :ticket_number je ažuriran od strane klijenta :contact',
    'ticket_new_template_subject' => 'Radni nalog :ticket_number je stvoren.',
    'ticket_updated_template_subject' => 'Radni nalog :ticket_number je ažuriran.',
    'ticket_closed_template_subject' => 'Radni nalog :ticket_number je zatvoren.',
    'ticket_overdue_template_subject' => 'Radni nalog :ticket_number kasni.',
    'merge' => 'Spoji',
    'merged' => 'Spojeno',
    'agent' => 'Agent',
    'parent_ticket' => 'Parent Ticket',
    'linked_tickets' => 'Povezani radni nalozi',
    'merge_prompt' => 'Unesite broj ranog naloga u kojeg će se spojiti',
    'merge_from_to' => 'Radni nalog #:old_ticket je spojen u radni nalog #:new_ticket',
    'merge_closed_ticket_text' => 'Radni nalog #:old_ticket je zatvoren i spojen u radni nalog #:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Radni nalog #:old_ticket je zatvoren i spojen s ovime',
    'merge_placeholder' => 'Spoji radni nalog #:ticket u sljedeći radni nalog',
    'select_ticket' => 'Odaberi radni nalog',
    'new_internal_ticket' => 'Novi interni radni nalog',
    'internal_ticket' => 'Interni radni nalog',
    'create_ticket' => 'Stvori radni nalog',
    'allow_inbound_email_tickets_external' => 'Novi radni nalog putem e-maila (Klijent)',
    'allow_inbound_email_tickets_external_help' => 'Dozvoli klijentima da kreiraju novi radni nalog putem e-maila',
    'include_in_filter' => 'Uključi u filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Usporedi',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Zahvaljujemo na strpljenju dok radimo na implementaciji ovih značajki.\n\ nNadajmo se da će ih dovršiti u sljedećih nekoliko mjeseci. \n\n A do tada ćemo nastaviti podržavati',
    'legacy_mobile_app' => 'legacy mobilnu aplikaciju ',
    'today' => 'Danas',
    'current' => 'Trenutni',
    'previous' => 'Prijašnji',
    'current_period' => 'Tekuće Razdoblje',
    'comparison_period' => 'Razdoblje usporedbe',
    'previous_period' => 'Prethodno razdoblje',
    'previous_year' => 'Prethodna godina',
    'compare_to' => 'Usporedi s',
    'last_week' => 'Prošli tjedan',
    'clone_to_invoice' => 'Kloniraj u Račune',
    'clone_to_quote' => 'Kloniraj u Ponude',
    'convert' => 'Pretvori',
    'last7_days' => 'Zadnjih 7 dana',
    'last30_days' => 'Zadnjih 30 dana',
    'custom_js' => 'Prilagođeni JS',
    'adjust_fee_percent_help' => 'Prilagodite postotak da biste uzeli u obzir naknadu',
    'show_product_notes' => 'Prikaži detalje o proizvodu',
    'show_product_notes_help' => 'Uključite <b>opis i cijenu</b> u padajući izbornik proizvoda',
    'important' => 'Važno',
    'thank_you_for_using_our_app' => 'Hvala vam što koristite našu aplikaciju!',
    'if_you_like_it' => 'Ako vam se sviđa, molim vas',
    'to_rate_it' => 'da bi ju ocijenili.',
    'average' => 'Prosjek',
    'unapproved' => 'Neodobreno',
    'authenticate_to_change_setting' => 'Potvrdite autentičnost da biste promijenili ovu postavku',
    'locked' => 'Zaključano',
    'authenticate' => 'Provjera autentičnosti',
    'please_authenticate' => 'Molimo provjerite autentičnost',
    'biometric_authentication' => 'Biometrijska provjera autentičnosti',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budžet',
    'please_enter_a_name' => 'Molimo unesite ime',
    'click_plus_to_add_time' => 'Pritisnite + za dodavanje vremena',
    'design' => 'Dizajn',
    'password_is_too_short' => 'Lozinka je prekratka',
    'failed_to_find_record' => 'Pronalaženje zapisa nije uspjelo',
    'valid_until_days' => 'Vrijedi do',
    'valid_until_days_help' => 'Automatski postavlja vrijednost <b>Važi do</b> u ponudama na ovoliko dana u budućnosti. Ostavite prazno da biste onemogućili.',
    'usually_pays_in_days' => 'Dana',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Fotografiraj',
    'upload_file' => 'Prenesi datoteku',
    'new_document' => 'Novi Dokument',
    'edit_document' => 'Uredi Dokument',
    'uploaded_document' => 'Uspješno preneseni dokument',
    'updated_document' => 'Uspješno ažurirani dokument',
    'archived_document' => 'Uspješno arhiviran dokument',
    'deleted_document' => 'Uspješno izbrisani dokument',
    'restored_document' => 'Uspješno vraćeni dokument',
    'no_history' => 'Nema povijesti',
    'expense_status_1' => 'Evidentirano',
    'expense_status_2' => 'U obradi',
    'expense_status_3' => 'Fakturirano',
    'no_record_selected' => 'Nije odabran nijedan zapis',
    'error_unsaved_changes' => 'Spremite ili poništite svoje promjene',
    'thank_you_for_your_purchase' => 'Hvala vam na kupnji!',
    'redeem' => 'Redeem',
    'back' => 'Natrag',
    'past_purchases' => 'Prošle kupnje',
    'annual_subscription' => 'Godišnja pretplata',
    'pro_plan' => 'Pro plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count korisnika',
    'upgrade' => 'Nadogradi',
    'please_enter_a_first_name' => 'Molimo unesite ime',
    'please_enter_a_last_name' => 'Molimo unesite prezime',
    'please_agree_to_terms_and_privacy' => 'Molimo vas da se složite s uvjetima pružanja usluge i pravilima o privatnosti za stvaranje računa.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'uvjetima pružanja usluge',
    'privacy_policy_link' => 'politika privatnosti',
    'view_website' => 'Pogledajte web stranicu',
    'create_account' => 'Otvori račun',
    'email_login' => 'Prijava putem e-pošte',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Broj transakcije',
    'before_due_date' => 'Prije datuma dospijeća',
    'after_due_date' => 'Nakon datuma dospijeća',
    'after_invoice_date' => 'Nakon datuma računa',
    'filtered_by_user' => 'Filtrirano po korisniku',
    'created_user' => 'Uspješno stvoren korisnik',
    'primary_font' => 'Primarni font',
    'secondary_font' => 'Sekundarni font',
    'number_padding' => 'Number Padding',
    'general' => 'Općenito',
    'surcharge_field' => 'Polje doplate',
    'company_value' => 'Vrijednost tvrtke',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Polje transakcije',
    'group_field' => 'Polje Grupe',
    'number_counter' => 'Brojač brojeva',
    'number_pattern' => 'Uzorak broja',
    'custom_javascript' => 'Prilagođeni JavaScript',
    'portal_mode' => 'Način rada Portal',
    'attach_pdf' => 'Priložite PDF',
    'attach_documents' => 'Priložite dokumente',
    'attach_ubl' => 'Priložite UBL',
    'email_style' => 'Stil e-pošte',
    'processed' => 'Obrađeno',
    'fee_amount' => 'Iznos naknade',
    'fee_percent' => 'Postotak naknade',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limiti/Naknade',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Zatražite od klijenta da navede svoju adresu za naplatu',
    'require_shipping_address_help' => 'Zatražite od klijenta da navede adresu za dostavu',
    'deleted_tax_rate' => 'Uspješno izbrisana porezna stopa',
    'restored_tax_rate' => 'Uspješno vraćena porezna stopa',
    'provider' => 'Dobavljač',
    'company_gateway' => 'Sustav online plaćanja',
    'company_gateways' => 'Sustavi online plaćanja',
    'new_company_gateway' => 'Novi sustav online plaćanja',
    'edit_company_gateway' => 'Uredi sustav online plaćanja',
    'created_company_gateway' => 'Uspješno stvoren Sustav online plaćanja',
    'updated_company_gateway' => 'Uspješno ažuriran sustav online plaćanja',
    'archived_company_gateway' => 'Uspješno arhiviran sustav online plaćanja',
    'deleted_company_gateway' => 'Uspješno izbrisan sustav online plaćanja',
    'restored_company_gateway' => 'Uspješno vraćen sustav online plaćanja',
    'continue_editing' => 'Nastavi uređivati',
    'default_value' => 'Zadana vrijednost',
    'currency_format' => 'Format valute',
    'first_day_of_the_week' => 'Prvi dan u tjednu',
    'first_month_of_the_year' => 'Prvi mjesec u godini',
    'symbol' => 'Simbol',
    'ocde' => 'Code',
    'date_format' => 'Format datuma',
    'datetime_format' => 'Format vremena',
    'send_reminders' => 'Pošalji podsjetnike',
    'timezone' => 'Vremenska zona',
    'filtered_by_group' => 'Filtrirano po grupi',
    'filtered_by_invoice' => 'Filtrirano po računu',
    'filtered_by_client' => 'Filtrirano po klijentu',
    'filtered_by_vendor' => 'Filtrirano po dobavljaču ',
    'group_settings' => 'Postavke grupe',
    'groups' => 'Grupe',
    'new_group' => 'Nova grupa',
    'edit_group' => 'Uredi grupu',
    'created_group' => 'Grupa je uspješno stvorena',
    'updated_group' => 'Grupa je uspješno ažurirana',
    'archived_group' => 'Grupa je uspješno arhivirana',
    'deleted_group' => 'Grupa je uspješno izbrisana',
    'restored_group' => 'Grupa je uspješno vraćena',
    'upload_logo' => 'Prenesi logo',
    'uploaded_logo' => 'Uspješno preneseni logo',
    'saved_settings' => 'Postavke uspješno spremljene',
    'device_settings' => 'Postavke uređaja',
    'credit_cards_and_banks' => 'Kreditne kartice i banke',
    'price' => 'Cijena',
    'email_sign_up' => 'Registrirajte se e-poštom',
    'google_sign_up' => 'Registrirajte se putem Google računa',
    'sign_up_with_google' => 'Registrirajte se putem Google računa',
    'long_press_multiselect' => 'Dugo pritisnite za višestruku odabir',
    'migrate_to_next_version' => 'Prelazak na sljedeću verziju aplikacije Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migracija',
    'welcome_to_the_new_version' => 'Dobrodošli u novu verziju Invoice Ninje',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Pritisnite gumb ispod kako biste preuzeli podatke.',
    'migration_import' => 'Super! Sada ste spremni uvesti migracijske datoteke. Idite na novu instalaciju da biste uvezli svoje podatke',
    'continue' => 'Nastavi',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Broj',
    'count' => 'Zbroj',
    'is_active' => 'Je aktivan',
    'contact_last_login' => 'Zadnje prijavljivanje kontakta',
    'contact_full_name' => 'Puno ime kontakta',
    'contact_custom_value1' => 'Prilagođena vrijednost 1 kontakta ',
    'contact_custom_value2' => 'Prilagođena vrijednost 2 kontakta ',
    'contact_custom_value3' => 'Prilagođena vrijednost 3 kontakta',
    'contact_custom_value4' => 'Prilagođena vrijednost 4 kontakta',
    'assigned_to_id' => 'Dodijeljeno ID-u',
    'created_by_id' => 'Stvorio ID',
    'add_column' => 'Dodaj stupac',
    'edit_columns' => 'Uredi stupce',
    'to_learn_about_gogle_fonts' => 'da biste saznali više o Google fontovima',
    'refund_date' => 'Datum povrata novca',
    'multiselect' => 'Višestruki odabir',
    'verify_password' => 'Potvrdi lozinku',
    'applied' => 'Primijenjeno',
    'include_recent_errors' => 'Uključite nedavne pogreške iz zapisnika',
    'your_message_has_been_received' => 'Primili smo vašu poruku i pokušat ćemo brzo odgovoriti.',
    'show_product_details' => 'Prikaži detalje o proizvodu',
    'show_product_details_help' => 'Uključite opis i cijenu u padajući izbornik proizvoda',
    'pdf_min_requirements' => 'PDF renderer zahtijeva :version',
    'adjust_fee_percent' => 'Prilagodite postotak naknade',
    'configure_settings' => 'Konfigurirajte postavke',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'URL domene',
    'password_is_too_easy' => 'Lozinka mora sadržavati barem jedno veliko slovo i broj',
    'client_portal_tasks' => 'Zadaci klijentskog portala',
    'client_portal_dashboard' => 'Nadzorna ploča klijentskog portala',
    'please_enter_a_value' => 'Molimo unesite vrijednost',
    'deleted_logo' => 'Logo je uspješno izbrisan',
    'generate_number' => 'Generiraj broj',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Odaberite tvrtku',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Pokaži/Sakrij',
    'menu_sidebar' => 'Bočna traka izbornika',
    'history_sidebar' => 'Bočna traka povijesti',
    'tablet' => 'Tablet',
    'layout' => 'Raspored',
    'module' => 'Module',
    'first_custom' => 'Prvi stupac',
    'second_custom' => 'Drugi stupac',
    'third_custom' => 'Treći stupac',
    'show_cost' => 'Prikaži trošak',
    'show_cost_help' => 'Prikaži polje troškova proizvoda za praćenje marže / dobiti',
    'show_product_quantity' => 'Prikaži količinu proizvoda',
    'show_product_quantity_help' => 'Prikaži polje s količinom proizvoda, inače zadano 1',
    'show_invoice_quantity' => 'Prikaži količinu računa',
    'show_invoice_quantity_help' => 'Prikaži polje za količinu stavke, inače zadano 1',
    'default_quantity' => 'Zadana količina',
    'default_quantity_help' => 'Količina stavke retka automatski postavi na 1',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Tekst u jednom retku',
    'multi_line_text' => 'Tekst s više redaka',
    'dropdown' => 'Padajući izbornik',
    'field_type' => 'Vrsta polja',
    'recover_password_email_sent' => 'Poslan je e-mail za oporavak lozinke',
    'removed_user' => 'Korisnik je uspješno uklonjen',
    'freq_three_years' => 'Tri godine',
    'military_time_help' => '24-satni prikaz',
    'click_here_capital' => 'Kliknite ovdje',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Računi su uspješno označeni kao poslani',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'Sustav nije uspio poslati račun e-poštom :invoice',
    'custom_value3' => 'Prilagođena vrijednost 3',
    'custom_value4' => 'Prilagođena vrijednost 4',
    'email_style_custom' => 'Prilagođeni stil e-pošte',
    'custom_message_dashboard' => 'Prilagođena poruka nadzorne ploče',
    'custom_message_unpaid_invoice' => 'Prilagođena poruka neplaćenog računa',
    'custom_message_paid_invoice' => 'Prilagođena poruka plaćenog računa',
    'custom_message_unapproved_quote' => 'Prilagođena poruka ne odobrene ponude',
    'lock_sent_invoices' => 'Zaključaj poslane račune',
    'translations' => 'Prijevodi',
    'task_number_pattern' => 'Uzorak broja zadatka',
    'task_number_counter' => 'Brojač broja zadatka',
    'expense_number_pattern' => 'Uzorak broja troškova',
    'expense_number_counter' => 'Brojač broja troškova',
    'vendor_number_pattern' => 'Uzorak broja dobavljača',
    'vendor_number_counter' => 'Brojač brojeva dobavljača',
    'ticket_number_pattern' => 'Uzorak broja radnog naloga',
    'ticket_number_counter' => 'Brojač broj radnog naloga',
    'payment_number_pattern' => 'Uzorak broja transakcije',
    'payment_number_counter' => 'Brojač broja transakcije',
    'invoice_number_pattern' => 'Uzorak broja računa',
    'quote_number_pattern' => 'Uzorak broja ponude',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Poništi datum brojača',
    'counter_padding' => 'Ispuna broja brojača',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Grad klijenta',
    'client_state' => 'Županija klijenta',
    'client_country' => 'Država klijenta',
    'client_is_active' => 'Klijent je aktivan',
    'client_balance' => 'Stanje računa klijenta',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Porezna stopa 1',
    'tax_rate2' => 'Porezna stopa 2',
    'tax_rate3' => 'Porezna stopa 3',
    'archived_at' => 'Arhivirano u',
    'has_expenses' => 'Ima troškove',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Izbrisan',
    'vendor_city' => 'Grad dobavljača',
    'vendor_state' => 'Županija dobavljača',
    'vendor_country' => 'Država dobavljača',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Tvrtka bez naziva',
    'added_company' => 'Tvrtka je uspješno dodana',
    'supported_events' => 'Podržani događaji',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Neobavezno',
    'license' => 'Licenca',
    'invoice_balance' => 'Stanje računa',
    'saved_design' => 'Uspješno spremljen dizajn',
    'client_details' => 'Pojedinosti o klijentu',
    'company_address' => 'Adresa tvrtke',
    'quote_details' => 'Pojedinosti o ponudi',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Stupci proizvoda',
    'task_columns' => 'Stupci zadatka',
    'add_field' => 'Dodaj polje',
    'all_events' => 'Svi događaji',
    'owned' => 'U vlasništvu',
    'payment_success' => 'Uspjeh plaćanja',
    'payment_failure' => 'Neuspjeh plaćanja',
    'quote_sent' => 'Ponuda poslana',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Račun pregledan',
    'quote_viewed' => 'Ponuda pogledana',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Ponuda odobrena',
    'receive_all_notifications' => 'Primi sve obavijesti',
    'purchase_license' => 'Kupi licencu',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Ponuda uspješno pretvorena',
    'credit_design' => 'Credit Design',
    'includes' => 'Uključuje',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Prilagođeni dizajni',
    'designs' => 'Dizajni',
    'new_design' => 'Novi dizajn',
    'edit_design' => 'Uredi dizajn',
    'created_design' => 'Dizajn uspješno stvoren',
    'updated_design' => 'Dizajn uspješno ažuriran',
    'archived_design' => 'Dizajn uspješno arhiviran',
    'deleted_design' => 'Dizajn uspješno izbrisan',
    'removed_design' => 'Dizajn uspješno uklonjen',
    'restored_design' => 'Dizajn uspješno vraćen',
    'recurring_tasks' => 'Ponavljajući zadaci',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Najnovija verzija',
    'update_now' => 'Ažuriraj sada',
    'a_new_version_is_available' => 'Dostupna je nova verzija web aplikacije',
    'update_available' => 'Ažuriranje dostupno',
    'app_updated' => 'Ažuriranje je uspješno završeno',
    'integrations' => 'Integracije',
    'tracking_id' => 'Broj za praćenje',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Djelomično plaćanje',
    'partial_payment_email' => 'E-pošta za djelomično plaćanje',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Odobreno je',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Klijent nema postavljenu adresu e-pošte',
    'ledger' => 'Ledger',
    'view_pdf' => 'Pogledaj PDF',
    'all_records' => 'Svi zapisi',
    'owned_by_user' => 'Vlasništvo korisnika',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Upotrijebi zadanu vrijednost',
    'reminder_endless' => 'Beskrajni podsjetnici',
    'number_of_days' => 'Broj dana',
    'configure_payment_terms' => 'Konfiguriraj rokove plaćanja',
    'payment_term' => 'Rok plaćanja',
    'new_payment_term' => 'Novi rok plaćanja',
    'deleted_payment_term' => 'Uspješno izbrisan rok plaćanja',
    'removed_payment_term' => 'Uspješno uklonjen rok plaćanja',
    'restored_payment_term' => 'Uspješno vraćen rok plaćanja',
    'full_width_editor' => 'Uređivač pune širine',
    'full_height_filter' => 'Filter pune visine',
    'email_sign_in' => 'Prijavite se e-poštom',
    'change' => 'Promijeni',
    'change_to_mobile_layout' => 'Promijeni na mobilni izgled?',
    'change_to_desktop_layout' => 'Promijeni na izgled stolnog računala',
    'send_from_gmail' => 'Pošalji s Gmaila',
    'reversed' => 'Stornirano',
    'cancelled' => 'Otkazani',
    'quote_amount' => 'Iznos Ponude',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Sakri Izbornik',
    'show_menu' => 'Prikaži Izbornik',
    'partially_refunded' => 'Djelomičan Povrat',
    'search_documents' => 'Pretraži Dokumente',
    'search_designs' => 'Pretraži Dizajne',
    'search_invoices' => 'Pretraži Račune',
    'search_clients' => 'Pretraži Klijente',
    'search_products' => 'Pretraži proizvode',
    'search_quotes' => 'Pretraži Ponude',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Pretraži Dobavljača ',
    'search_users' => 'Pretraži Korisnike',
    'search_tax_rates' => 'Pretraži porezne stope',
    'search_tasks' => 'Pretraži Zadatke',
    'search_settings' => 'Pretraži Postavke',
    'search_projects' => 'Pretraži projekte',
    'search_expenses' => 'Pretraži troškove',
    'search_payments' => 'Pretraži Uplate',
    'search_groups' => 'Pretraži Grupe',
    'search_company' => 'Pretraži Poduzeće',
    'cancelled_invoice' => 'Uspješno otkazani račun',
    'cancelled_invoices' => 'Uspješno otkazani račun',
    'reversed_invoice' => 'Uspješno otkazani računi',
    'reversed_invoices' => 'Uspješno storniran račun',
    'reverse' => 'Storniraj',
    'filtered_by_project' => 'Filtrirano po Projektu ',
    'google_sign_in' => 'Prijavite se s Google računom',
    'activity_58' => ':user je stornirao račun :invoice',
    'activity_59' => ':user otkazao račun :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email poslan',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Neuspjeh',
    'quota_exceeded' => 'Kvota premašena',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'Zapisnici sustava',
    'copy_link' => 'Kopiraj link',
    'welcome_to_invoice_ninja' => 'Dobrodošli u Invoice Ninja',
    'optin' => 'Dragovoljno sudjeluj',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Automatski pretvoriti',
    'reminder1_sent' => 'Podsjetnik 1 poslan',
    'reminder2_sent' => 'Podsjetnik 2 poslan',
    'reminder3_sent' => 'Podsjetnik 3 poslan',
    'reminder_last_sent' => 'Podsjetnik 4 poslan',
    'pdf_page_info' => 'Stranica :current od :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'Pogled u aplikaciji Stripe',
    'rows_per_page' => 'Redova po stranici',
    'apply_payment' => 'Izvrši plaćanje',
    'unapplied' => 'Neprovedeni',
    'custom_labels' => 'Prilagođene oznake',
    'record_type' => 'Vrsta zapisa',
    'record_name' => 'Ime zapisa',
    'file_type' => 'Vrsta datoteke',
    'height' => 'Visina',
    'width' => 'Širina',
    'health_check' => 'Provjera zdravlja',
    'last_login_at' => 'Posljednja prijava u',
    'company_key' => 'Ključ tvrtke',
    'storefront' => 'Storefront',
    'storefront_help' => 'Omogućite aplikacijama trećih strana za stvaranje računa',
    'count_records_selected' => ':count odabranih zapisa',
    'count_record_selected' => ':count odabranih zapisa',
    'client_created' => 'Klijent stvoren',
    'online_payment_email' => 'E-pošta za internetsko plaćanje',
    'manual_payment_email' => 'E-pošta za ručno plaćanje',
    'completed' => 'Dovršeno',
    'gross' => 'Bruto',
    'net_amount' => 'Neto iznos',
    'net_balance' => 'Neto saldo',
    'client_settings' => 'Postavke klijenta',
    'selected_invoices' => 'Odabrani računi',
    'selected_payments' => 'Odabrane transkacije',
    'selected_quotes' => 'Odabrane ponude',
    'selected_tasks' => 'Odabrani zadaci',
    'selected_expenses' => 'Odabrani troškovi',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Ažuriraj ponudi',
    'update_invoice' => 'Ažuriraj račun',
    'update_client' => 'Ažuriraj klijenta',
    'update_vendor' => 'Ažuriraj dobavljača ',
    'create_expense' => 'Stvori trošak',
    'update_expense' => 'Ažuriraj trošak',
    'update_task' => 'Ažuriraj zadatak',
    'approve_quote' => 'Odobri ponudu',
    'when_paid' => 'When Paid',
    'expires_on' => 'Istječe u',
    'show_sidebar' => 'Pokaži bočnu traku',
    'hide_sidebar' => 'Sakrij bočnu traku',
    'event_type' => 'Vrsta događaja',
    'copy' => 'Kopiraj',
    'must_be_online' => 'Ponovo pokrenite aplikaciju nakon povezivanja s internetom',
    'crons_not_enabled' => 'CRON zadatak mora biti postavljen',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Pretraži :count Webhooks',
    'search_webhook' => 'Pretraži 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'Novi Webhook',
    'edit_webhook' => 'Uredi Webhook',
    'created_webhook' => 'Webhook uspješno stvoren',
    'updated_webhook' => 'Webhook uspješno ažuriran',
    'archived_webhook' => 'Webhook uspješno arhiviran',
    'deleted_webhook' => 'Webhook uspješno izbrisan',
    'removed_webhook' => 'Webhook uspješno uklonjen',
    'restored_webhook' => 'Webhook uspješno vraćen',
    'search_tokens' => 'Pretraži :count tokena',
    'search_token' => 'Pretraži 1 token',
    'new_token' => 'Novi token',
    'removed_token' => 'Token uspješno uklonjen',
    'restored_token' => 'Token uspješno vraćen',
    'client_registration' => 'Registracija klijenta',
    'client_registration_help' => 'Omogućite klijentima da se sami registriraju na portalu',
    'customize_and_preview' => 'Prilagodba i pregled',
    'search_document' => 'Pretraži 1 dokument',
    'search_design' => 'Pretraži 1 dizajn',
    'search_invoice' => 'Pretraži 1 račun',
    'search_client' => 'Pretraži 1 klijenta',
    'search_product' => 'Pretraži 1 proizvod',
    'search_quote' => 'Pretraži 1 ponudu',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Pretraži 1 dobavljača',
    'search_user' => 'Pretraži 1 korisnika',
    'search_tax_rate' => 'Pretraži 1 poreznu stopu',
    'search_task' => 'Pretraži 1 zadatka',
    'search_project' => 'Pretraži 1 projekta',
    'search_expense' => 'Pretraži 1 troška',
    'search_payment' => 'Pretraži 1 transakciju',
    'search_group' => 'Pretraži 1 grupu',
    'created_on' => 'Stvoreno u',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Zaključaj račune',
    'show_table' => 'Prikaz u tablici',
    'show_list' => 'Prikaz u listi',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
